import typing

import android.app
import android.content
import android.os
import java
import java.io
import java.lang

class SipAudioCall(java.lang.Object):
    def __init__(self, context: android.content.Context, localProfile: SipProfile, /) -> None: ...
    def answerCall(self, timeout: int | java.jint | java.lang.Integer, /) -> None: ...
    def attachCall(self, session: SipSession, sessionDescription: str | java.lang.String, /) -> None: ...
    def close(self) -> None: ...
    def continueCall(self, timeout: int | java.jint | java.lang.Integer, /) -> None: ...
    def endCall(self) -> None: ...
    def getLocalProfile(self) -> SipProfile: ...
    def getPeerProfile(self) -> SipProfile: ...
    def getState(self) -> int: ...
    def holdCall(self, timeout: int | java.jint | java.lang.Integer, /) -> None: ...
    def isInCall(self) -> bool: ...
    def isMuted(self) -> bool: ...
    def isOnHold(self) -> bool: ...
    def makeCall(self, peerProfile: SipProfile, sipSession: SipSession, timeout: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def sendDtmf(self, code: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def sendDtmf(self, code: int | java.jint | java.lang.Integer, result: android.os.Message, /) -> None: ...
    @typing.overload
    def setListener(self, listener: SipAudioCall.Listener, /) -> None: ...
    @typing.overload
    def setListener(self, listener: SipAudioCall.Listener, callbackImmediately: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setSpeakerMode(self, speakerMode: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def startAudio(self) -> None: ...
    def toggleMute(self) -> None: ...

    class Listener(java.lang.Object):
        def __init__(self) -> None: ...
        def onCallBusy(self, call: SipAudioCall, /) -> None: ...
        def onCallEnded(self, call: SipAudioCall, /) -> None: ...
        def onCallEstablished(self, call: SipAudioCall, /) -> None: ...
        def onCallHeld(self, call: SipAudioCall, /) -> None: ...
        def onCalling(self, call: SipAudioCall, /) -> None: ...
        def onChanged(self, call: SipAudioCall, /) -> None: ...
        def onError(self, call: SipAudioCall, errorCode: int | java.jint | java.lang.Integer, errorMessage: str | java.lang.String, /) -> None: ...
        def onReadyToCall(self, call: SipAudioCall, /) -> None: ...
        def onRinging(self, call: SipAudioCall, caller: SipProfile, /) -> None: ...
        def onRingingBack(self, call: SipAudioCall, /) -> None: ...

class SipErrorCode(java.lang.Object):
    CLIENT_ERROR: typing.ClassVar[int] = ...
    CROSS_DOMAIN_AUTHENTICATION: typing.ClassVar[int] = ...
    DATA_CONNECTION_LOST: typing.ClassVar[int] = ...
    INVALID_CREDENTIALS: typing.ClassVar[int] = ...
    INVALID_REMOTE_URI: typing.ClassVar[int] = ...
    IN_PROGRESS: typing.ClassVar[int] = ...
    NO_ERROR: typing.ClassVar[int] = ...
    PEER_NOT_REACHABLE: typing.ClassVar[int] = ...
    SERVER_ERROR: typing.ClassVar[int] = ...
    SERVER_UNREACHABLE: typing.ClassVar[int] = ...
    SOCKET_ERROR: typing.ClassVar[int] = ...
    TIME_OUT: typing.ClassVar[int] = ...
    TRANSACTION_TERMINTED: typing.ClassVar[int] = ...
    @staticmethod
    def toString(errorCode: int | java.jint | java.lang.Integer, /) -> str: ...

class SipException(java.lang.Exception):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...

class SipManager(java.lang.Object):
    EXTRA_CALL_ID: typing.ClassVar[str] = ...
    EXTRA_OFFER_SD: typing.ClassVar[str] = ...
    INCOMING_CALL_RESULT_CODE: typing.ClassVar[int] = ...
    def close(self, localProfileUri: str | java.lang.String, /) -> None: ...
    def createSipSession(self, localProfile: SipProfile, listener: SipSession.Listener, /) -> SipSession: ...
    @staticmethod
    def getCallId(incomingCallIntent: android.content.Intent, /) -> str | None: ...
    @staticmethod
    def getOfferSessionDescription(incomingCallIntent: android.content.Intent, /) -> str | None: ...
    def getSessionFor(self, incomingCallIntent: android.content.Intent, /) -> SipSession: ...
    @staticmethod
    def isApiSupported(context: android.content.Context, /) -> bool: ...
    @staticmethod
    def isIncomingCallIntent(intent: android.content.Intent, /) -> bool: ...
    def isOpened(self, localProfileUri: str | java.lang.String, /) -> bool: ...
    def isRegistered(self, localProfileUri: str | java.lang.String, /) -> bool: ...
    @staticmethod
    def isSipWifiOnly(context: android.content.Context, /) -> bool: ...
    @staticmethod
    def isVoipSupported(context: android.content.Context, /) -> bool: ...
    @typing.overload
    def makeAudioCall(self, localProfile: SipProfile, peerProfile: SipProfile, listener: SipAudioCall.Listener, timeout: int | java.jint | java.lang.Integer, /) -> SipAudioCall: ...
    @typing.overload
    def makeAudioCall(self, localProfileUri: str | java.lang.String, peerProfileUri: str | java.lang.String, listener: SipAudioCall.Listener, timeout: int | java.jint | java.lang.Integer, /) -> SipAudioCall: ...
    @staticmethod
    def newInstance(context: android.content.Context, /) -> SipManager | None: ...
    @typing.overload
    def open(self, localProfile: SipProfile, /) -> None: ...
    @typing.overload
    def open(self, localProfile: SipProfile, incomingCallPendingIntent: android.app.PendingIntent, listener: SipRegistrationListener, /) -> None: ...
    def register(self, localProfile: SipProfile, expiryTime: int | java.jint | java.lang.Integer, listener: SipRegistrationListener, /) -> None: ...
    def setRegistrationListener(self, localProfileUri: str | java.lang.String, listener: SipRegistrationListener, /) -> None: ...
    def takeAudioCall(self, incomingCallIntent: android.content.Intent, listener: SipAudioCall.Listener, /) -> SipAudioCall: ...
    def unregister(self, localProfile: SipProfile, listener: SipRegistrationListener, /) -> None: ...

class SipProfile(android.os.Parcelable, java.io.Serializable, java.lang.Cloneable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SipProfile]] = ...
    def describeContents(self) -> int: ...
    def getAuthUserName(self) -> str: ...
    def getAutoRegistration(self) -> bool: ...
    def getDisplayName(self) -> str: ...
    def getPassword(self) -> str: ...
    def getPort(self) -> int: ...
    def getProfileName(self) -> str: ...
    def getProtocol(self) -> str: ...
    def getProxyAddress(self) -> str: ...
    def getSendKeepAlive(self) -> bool: ...
    def getSipDomain(self) -> str: ...
    def getUriString(self) -> str: ...
    def getUserName(self) -> str: ...
    def setCallingUid(self, uid: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self, profile: SipProfile, /) -> None: ...
        @typing.overload
        def __init__(self, uriString: str | java.lang.String, /) -> None: ...
        @typing.overload
        def __init__(self, username: str | java.lang.String, serverDomain: str | java.lang.String, /) -> None: ...
        def build(self) -> SipProfile: ...
        def setAuthUserName(self, name: str | java.lang.String, /) -> SipProfile.Builder: ...
        def setAutoRegistration(self, flag: bool | java.jboolean | java.lang.Boolean, /) -> SipProfile.Builder: ...
        def setDisplayName(self, displayName: str | java.lang.String, /) -> SipProfile.Builder: ...
        def setOutboundProxy(self, outboundProxy: str | java.lang.String, /) -> SipProfile.Builder: ...
        def setPassword(self, password: str | java.lang.String, /) -> SipProfile.Builder: ...
        def setPort(self, port: int | java.jint | java.lang.Integer, /) -> SipProfile.Builder: ...
        def setProfileName(self, name: str | java.lang.String, /) -> SipProfile.Builder: ...
        def setProtocol(self, protocol: str | java.lang.String, /) -> SipProfile.Builder: ...
        def setSendKeepAlive(self, flag: bool | java.jboolean | java.lang.Boolean, /) -> SipProfile.Builder: ...

class SipRegistrationListener(java.lang.Object):
    def onRegistering(self, arg1: str | java.lang.String, /) -> None: ...
    def onRegistrationDone(self, arg1: str | java.lang.String, arg2: int | java.jlong | java.lang.Long, /) -> None: ...
    def onRegistrationFailed(self, arg1: str | java.lang.String, arg2: int | java.jint | java.lang.Integer, arg3: str | java.lang.String, /) -> None: ...

class SipSession(java.lang.Object):
    def answerCall(self, sessionDescription: str | java.lang.String, timeout: int | java.jint | java.lang.Integer, /) -> None: ...
    def changeCall(self, sessionDescription: str | java.lang.String, timeout: int | java.jint | java.lang.Integer, /) -> None: ...
    def endCall(self) -> None: ...
    def getCallId(self) -> str: ...
    def getLocalIp(self) -> str: ...
    def getLocalProfile(self) -> SipProfile: ...
    def getPeerProfile(self) -> SipProfile: ...
    def getState(self) -> int: ...
    def isInCall(self) -> bool: ...
    def makeCall(self, callee: SipProfile, sessionDescription: str | java.lang.String, timeout: int | java.jint | java.lang.Integer, /) -> None: ...
    def register(self, duration: int | java.jint | java.lang.Integer, /) -> None: ...
    def setListener(self, listener: SipSession.Listener, /) -> None: ...
    def unregister(self) -> None: ...

    class State(java.lang.Object):
        DEREGISTERING: typing.ClassVar[int] = ...
        INCOMING_CALL: typing.ClassVar[int] = ...
        INCOMING_CALL_ANSWERING: typing.ClassVar[int] = ...
        IN_CALL: typing.ClassVar[int] = ...
        NOT_DEFINED: typing.ClassVar[int] = ...
        OUTGOING_CALL: typing.ClassVar[int] = ...
        OUTGOING_CALL_CANCELING: typing.ClassVar[int] = ...
        OUTGOING_CALL_RING_BACK: typing.ClassVar[int] = ...
        PINGING: typing.ClassVar[int] = ...
        READY_TO_CALL: typing.ClassVar[int] = ...
        REGISTERING: typing.ClassVar[int] = ...
        @staticmethod
        def toString(state: int | java.jint | java.lang.Integer, /) -> str: ...

    class Listener(java.lang.Object):
        def __init__(self) -> None: ...
        def onCallBusy(self, session: SipSession, /) -> None: ...
        def onCallChangeFailed(self, session: SipSession, errorCode: int | java.jint | java.lang.Integer, errorMessage: str | java.lang.String, /) -> None: ...
        def onCallEnded(self, session: SipSession, /) -> None: ...
        def onCallEstablished(self, session: SipSession, sessionDescription: str | java.lang.String, /) -> None: ...
        def onCalling(self, session: SipSession, /) -> None: ...
        def onError(self, session: SipSession, errorCode: int | java.jint | java.lang.Integer, errorMessage: str | java.lang.String, /) -> None: ...
        def onRegistering(self, session: SipSession, /) -> None: ...
        def onRegistrationDone(self, session: SipSession, duration: int | java.jint | java.lang.Integer, /) -> None: ...
        def onRegistrationFailed(self, session: SipSession, errorCode: int | java.jint | java.lang.Integer, errorMessage: str | java.lang.String, /) -> None: ...
        def onRegistrationTimeout(self, session: SipSession, /) -> None: ...
        def onRinging(self, session: SipSession, caller: SipProfile, sessionDescription: str | java.lang.String, /) -> None: ...
        def onRingingBack(self, session: SipSession, /) -> None: ...



import typing

import java
import java.chaquopy
import java.io
import java.lang
import java.lang.ref
import java.net
import java.nio

class ErrnoException(java.lang.Exception):
    errno: int = ...
    @typing.overload
    def __init__(self, functionName: str | java.lang.String, errno: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, functionName: str | java.lang.String, errno: int | java.jint | java.lang.Integer, cause: java.lang.Throwable, /) -> None: ...
    def getMessage(self) -> str: ...
    def rethrowAsIOException(self) -> java.io.IOException: ...
    def rethrowAsSocketException(self) -> java.net.SocketException: ...

class Int64Ref(java.lang.Object):
    value: int = ...
    def __init__(self, value: int | java.jlong | java.lang.Long, /) -> None: ...
    def toString(self) -> str: ...

class Os(java.lang.Object):
    @staticmethod
    def accept(fd: java.io.FileDescriptor, peerAddress: java.net.InetSocketAddress, /) -> java.io.FileDescriptor: ...
    @staticmethod
    def access(path: str | java.lang.String, mode: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    @staticmethod
    def bind(fd: java.io.FileDescriptor, address: java.net.SocketAddress, /) -> None: ...
    @typing.overload
    @staticmethod
    def bind(fd: java.io.FileDescriptor, address: java.net.InetAddress, port: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def chmod(path: str | java.lang.String, mode: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def chown(path: str | java.lang.String, uid: int | java.jint | java.lang.Integer, gid: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def close(fd: java.io.FileDescriptor, /) -> None: ...
    @typing.overload
    @staticmethod
    def connect(fd: java.io.FileDescriptor, address: java.net.SocketAddress, /) -> None: ...
    @typing.overload
    @staticmethod
    def connect(fd: java.io.FileDescriptor, address: java.net.InetAddress, port: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def dup(oldFd: java.io.FileDescriptor, /) -> java.io.FileDescriptor: ...
    @staticmethod
    def dup2(oldFd: java.io.FileDescriptor, newFd: int | java.jint | java.lang.Integer, /) -> java.io.FileDescriptor: ...
    @staticmethod
    def environ() -> java.chaquopy.JavaArray[java.lang.String]: ...
    @staticmethod
    def execv(filename: str | java.lang.String, argv: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    @staticmethod
    def execve(filename: str | java.lang.String, argv: java.chaquopy.JavaArray[java.lang.String], envp: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    @staticmethod
    def fchmod(fd: java.io.FileDescriptor, mode: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def fchown(fd: java.io.FileDescriptor, uid: int | java.jint | java.lang.Integer, gid: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def fcntlInt(fd: java.io.FileDescriptor, cmd: int | java.jint | java.lang.Integer, arg: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def fdatasync(fd: java.io.FileDescriptor, /) -> None: ...
    @staticmethod
    def fstat(fd: java.io.FileDescriptor, /) -> StructStat: ...
    @staticmethod
    def fstatvfs(fd: java.io.FileDescriptor, /) -> StructStatVfs: ...
    @staticmethod
    def fsync(fd: java.io.FileDescriptor, /) -> None: ...
    @staticmethod
    def ftruncate(fd: java.io.FileDescriptor, length: int | java.jlong | java.lang.Long, /) -> None: ...
    @staticmethod
    def gai_strerror(error: int | java.jint | java.lang.Integer, /) -> str: ...
    @staticmethod
    def getegid() -> int: ...
    @staticmethod
    def getenv(name: str | java.lang.String, /) -> str: ...
    @staticmethod
    def geteuid() -> int: ...
    @staticmethod
    def getgid() -> int: ...
    @staticmethod
    def getpeername(fd: java.io.FileDescriptor, /) -> java.net.SocketAddress: ...
    @staticmethod
    def getpid() -> int: ...
    @staticmethod
    def getppid() -> int: ...
    @staticmethod
    def getsockname(fd: java.io.FileDescriptor, /) -> java.net.SocketAddress: ...
    @staticmethod
    def getsockoptTimeval(fd: java.io.FileDescriptor, level: int | java.jint | java.lang.Integer, option: int | java.jint | java.lang.Integer, /) -> StructTimeval: ...
    @staticmethod
    def gettid() -> int: ...
    @staticmethod
    def getuid() -> int: ...
    @staticmethod
    def getxattr(path: str | java.lang.String, name: str | java.lang.String, /) -> java.chaquopy.JavaArrayJByte: ...
    @staticmethod
    def if_indextoname(index: int | java.jint | java.lang.Integer, /) -> str: ...
    @staticmethod
    def if_nametoindex(name: str | java.lang.String, /) -> int: ...
    @staticmethod
    def inet_pton(family: int | java.jint | java.lang.Integer, address: str | java.lang.String, /) -> java.net.InetAddress: ...
    @staticmethod
    def isatty(fd: java.io.FileDescriptor, /) -> bool: ...
    @staticmethod
    def kill(pid: int | java.jint | java.lang.Integer, signal: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def lchown(path: str | java.lang.String, uid: int | java.jint | java.lang.Integer, gid: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def link(oldPath: str | java.lang.String, newPath: str | java.lang.String, /) -> None: ...
    @staticmethod
    def listen(fd: java.io.FileDescriptor, backlog: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def listxattr(path: str | java.lang.String, /) -> java.chaquopy.JavaArray[java.lang.String]: ...
    @staticmethod
    def lseek(fd: java.io.FileDescriptor, offset: int | java.jlong | java.lang.Long, whence: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def lstat(path: str | java.lang.String, /) -> StructStat: ...
    @staticmethod
    def memfd_create(name: str | java.lang.String, flags: int | java.jint | java.lang.Integer, /) -> java.io.FileDescriptor: ...
    @staticmethod
    def mincore(address: int | java.jlong | java.lang.Long, byteCount: int | java.jlong | java.lang.Long, vector: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @staticmethod
    def mkdir(path: str | java.lang.String, mode: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def mkfifo(path: str | java.lang.String, mode: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def mlock(address: int | java.jlong | java.lang.Long, byteCount: int | java.jlong | java.lang.Long, /) -> None: ...
    @staticmethod
    def mmap(address: int | java.jlong | java.lang.Long, byteCount: int | java.jlong | java.lang.Long, prot: int | java.jint | java.lang.Integer, flags: int | java.jint | java.lang.Integer, fd: java.io.FileDescriptor, offset: int | java.jlong | java.lang.Long, /) -> int: ...
    @staticmethod
    def msync(address: int | java.jlong | java.lang.Long, byteCount: int | java.jlong | java.lang.Long, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def munlock(address: int | java.jlong | java.lang.Long, byteCount: int | java.jlong | java.lang.Long, /) -> None: ...
    @staticmethod
    def munmap(address: int | java.jlong | java.lang.Long, byteCount: int | java.jlong | java.lang.Long, /) -> None: ...
    @staticmethod
    def open(path: str | java.lang.String, flags: int | java.jint | java.lang.Integer, mode: int | java.jint | java.lang.Integer, /) -> java.io.FileDescriptor: ...
    @staticmethod
    def pipe() -> java.chaquopy.JavaArray[java.io.FileDescriptor]: ...
    @staticmethod
    def poll(fds: java.chaquopy.JavaArray[StructPollfd], timeoutMs: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def posix_fallocate(fd: java.io.FileDescriptor, offset: int | java.jlong | java.lang.Long, length: int | java.jlong | java.lang.Long, /) -> None: ...
    @staticmethod
    def prctl(option: int | java.jint | java.lang.Integer, arg2: int | java.jlong | java.lang.Long, arg3: int | java.jlong | java.lang.Long, arg4: int | java.jlong | java.lang.Long, arg5: int | java.jlong | java.lang.Long, /) -> int: ...
    @typing.overload
    @staticmethod
    def pread(fd: java.io.FileDescriptor, buffer: java.nio.ByteBuffer, offset: int | java.jlong | java.lang.Long, /) -> int: ...
    @typing.overload
    @staticmethod
    def pread(fd: java.io.FileDescriptor, bytes: java.chaquopy.JavaArrayJByte, byteOffset: int | java.jint | java.lang.Integer, byteCount: int | java.jint | java.lang.Integer, offset: int | java.jlong | java.lang.Long, /) -> int: ...
    @typing.overload
    @staticmethod
    def pwrite(fd: java.io.FileDescriptor, buffer: java.nio.ByteBuffer, offset: int | java.jlong | java.lang.Long, /) -> int: ...
    @typing.overload
    @staticmethod
    def pwrite(fd: java.io.FileDescriptor, bytes: java.chaquopy.JavaArrayJByte, byteOffset: int | java.jint | java.lang.Integer, byteCount: int | java.jint | java.lang.Integer, offset: int | java.jlong | java.lang.Long, /) -> int: ...
    @typing.overload
    @staticmethod
    def read(fd: java.io.FileDescriptor, buffer: java.nio.ByteBuffer, /) -> int: ...
    @typing.overload
    @staticmethod
    def read(fd: java.io.FileDescriptor, bytes: java.chaquopy.JavaArrayJByte, byteOffset: int | java.jint | java.lang.Integer, byteCount: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def readlink(path: str | java.lang.String, /) -> str: ...
    @staticmethod
    def readv(fd: java.io.FileDescriptor, buffers: java.chaquopy.JavaArray[java.lang.Object], offsets: java.chaquopy.JavaArrayJInt, byteCounts: java.chaquopy.JavaArrayJInt, /) -> int: ...
    @typing.overload
    @staticmethod
    def recvfrom(fd: java.io.FileDescriptor, buffer: java.nio.ByteBuffer, flags: int | java.jint | java.lang.Integer, srcAddress: java.net.InetSocketAddress, /) -> int: ...
    @typing.overload
    @staticmethod
    def recvfrom(fd: java.io.FileDescriptor, bytes: java.chaquopy.JavaArrayJByte, byteOffset: int | java.jint | java.lang.Integer, byteCount: int | java.jint | java.lang.Integer, flags: int | java.jint | java.lang.Integer, srcAddress: java.net.InetSocketAddress, /) -> int: ...
    @staticmethod
    def recvmsg(fd: java.io.FileDescriptor, msg: StructMsghdr, flags: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def remove(path: str | java.lang.String, /) -> None: ...
    @staticmethod
    def removexattr(path: str | java.lang.String, name: str | java.lang.String, /) -> None: ...
    @staticmethod
    def rename(oldPath: str | java.lang.String, newPath: str | java.lang.String, /) -> None: ...
    @staticmethod
    def sendfile(outFd: java.io.FileDescriptor, inFd: java.io.FileDescriptor, offset: Int64Ref, byteCount: int | java.jlong | java.lang.Long, /) -> int: ...
    @staticmethod
    def sendmsg(fd: java.io.FileDescriptor, msg: StructMsghdr, flags: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    @staticmethod
    def sendto(fd: java.io.FileDescriptor, buffer: java.nio.ByteBuffer, flags: int | java.jint | java.lang.Integer, inetAddress: java.net.InetAddress, port: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    @staticmethod
    def sendto(fd: java.io.FileDescriptor, bytes: java.chaquopy.JavaArrayJByte, byteOffset: int | java.jint | java.lang.Integer, byteCount: int | java.jint | java.lang.Integer, flags: int | java.jint | java.lang.Integer, address: java.net.SocketAddress, /) -> int: ...
    @typing.overload
    @staticmethod
    def sendto(fd: java.io.FileDescriptor, bytes: java.chaquopy.JavaArrayJByte, byteOffset: int | java.jint | java.lang.Integer, byteCount: int | java.jint | java.lang.Integer, flags: int | java.jint | java.lang.Integer, inetAddress: java.net.InetAddress, port: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def setegid(egid: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def setenv(name: str | java.lang.String, value: str | java.lang.String, overwrite: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @staticmethod
    def seteuid(euid: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def setgid(gid: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def setsid() -> int: ...
    @staticmethod
    def setsockoptInt(fd: java.io.FileDescriptor, level: int | java.jint | java.lang.Integer, option: int | java.jint | java.lang.Integer, value: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def setsockoptTimeval(fd: java.io.FileDescriptor, level: int | java.jint | java.lang.Integer, option: int | java.jint | java.lang.Integer, value: StructTimeval, /) -> None: ...
    @staticmethod
    def setuid(uid: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def setxattr(path: str | java.lang.String, name: str | java.lang.String, value: java.chaquopy.JavaArrayJByte, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def shutdown(fd: java.io.FileDescriptor, how: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def socket(domain: int | java.jint | java.lang.Integer, type: int | java.jint | java.lang.Integer, protocol: int | java.jint | java.lang.Integer, /) -> java.io.FileDescriptor: ...
    @staticmethod
    def socketpair(domain: int | java.jint | java.lang.Integer, type: int | java.jint | java.lang.Integer, protocol: int | java.jint | java.lang.Integer, fd1: java.io.FileDescriptor, fd2: java.io.FileDescriptor, /) -> None: ...
    @staticmethod
    def stat(path: str | java.lang.String, /) -> StructStat: ...
    @staticmethod
    def statvfs(path: str | java.lang.String, /) -> StructStatVfs: ...
    @staticmethod
    def strerror(errno: int | java.jint | java.lang.Integer, /) -> str: ...
    @staticmethod
    def strsignal(signal: int | java.jint | java.lang.Integer, /) -> str: ...
    @staticmethod
    def symlink(oldPath: str | java.lang.String, newPath: str | java.lang.String, /) -> None: ...
    @staticmethod
    def sysconf(name: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def tcdrain(fd: java.io.FileDescriptor, /) -> None: ...
    @staticmethod
    def tcsendbreak(fd: java.io.FileDescriptor, duration: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def umask(mask: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def uname() -> StructUtsname: ...
    @staticmethod
    def unsetenv(name: str | java.lang.String, /) -> None: ...
    @typing.overload
    @staticmethod
    def write(fd: java.io.FileDescriptor, buffer: java.nio.ByteBuffer, /) -> int: ...
    @typing.overload
    @staticmethod
    def write(fd: java.io.FileDescriptor, bytes: java.chaquopy.JavaArrayJByte, byteOffset: int | java.jint | java.lang.Integer, byteCount: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def writev(fd: java.io.FileDescriptor, buffers: java.chaquopy.JavaArray[java.lang.Object], offsets: java.chaquopy.JavaArrayJInt, byteCounts: java.chaquopy.JavaArrayJInt, /) -> int: ...

class OsConstants(java.lang.Object):
    AF_INET6: typing.ClassVar[int] = ...
    AF_INET: typing.ClassVar[int] = ...
    AF_NETLINK: typing.ClassVar[int] = ...
    AF_PACKET: typing.ClassVar[int] = ...
    AF_UNIX: typing.ClassVar[int] = ...
    AF_UNSPEC: typing.ClassVar[int] = ...
    AF_VSOCK: typing.ClassVar[int] = ...
    AI_ADDRCONFIG: typing.ClassVar[int] = ...
    AI_ALL: typing.ClassVar[int] = ...
    AI_CANONNAME: typing.ClassVar[int] = ...
    AI_NUMERICHOST: typing.ClassVar[int] = ...
    AI_NUMERICSERV: typing.ClassVar[int] = ...
    AI_PASSIVE: typing.ClassVar[int] = ...
    AI_V4MAPPED: typing.ClassVar[int] = ...
    ARPHRD_ETHER: typing.ClassVar[int] = ...
    CAP_AUDIT_CONTROL: typing.ClassVar[int] = ...
    CAP_AUDIT_WRITE: typing.ClassVar[int] = ...
    CAP_BLOCK_SUSPEND: typing.ClassVar[int] = ...
    CAP_CHOWN: typing.ClassVar[int] = ...
    CAP_DAC_OVERRIDE: typing.ClassVar[int] = ...
    CAP_DAC_READ_SEARCH: typing.ClassVar[int] = ...
    CAP_FOWNER: typing.ClassVar[int] = ...
    CAP_FSETID: typing.ClassVar[int] = ...
    CAP_IPC_LOCK: typing.ClassVar[int] = ...
    CAP_IPC_OWNER: typing.ClassVar[int] = ...
    CAP_KILL: typing.ClassVar[int] = ...
    CAP_LAST_CAP: typing.ClassVar[int] = ...
    CAP_LEASE: typing.ClassVar[int] = ...
    CAP_LINUX_IMMUTABLE: typing.ClassVar[int] = ...
    CAP_MAC_ADMIN: typing.ClassVar[int] = ...
    CAP_MAC_OVERRIDE: typing.ClassVar[int] = ...
    CAP_MKNOD: typing.ClassVar[int] = ...
    CAP_NET_ADMIN: typing.ClassVar[int] = ...
    CAP_NET_BIND_SERVICE: typing.ClassVar[int] = ...
    CAP_NET_BROADCAST: typing.ClassVar[int] = ...
    CAP_NET_RAW: typing.ClassVar[int] = ...
    CAP_SETFCAP: typing.ClassVar[int] = ...
    CAP_SETGID: typing.ClassVar[int] = ...
    CAP_SETPCAP: typing.ClassVar[int] = ...
    CAP_SETUID: typing.ClassVar[int] = ...
    CAP_SYSLOG: typing.ClassVar[int] = ...
    CAP_SYS_ADMIN: typing.ClassVar[int] = ...
    CAP_SYS_BOOT: typing.ClassVar[int] = ...
    CAP_SYS_CHROOT: typing.ClassVar[int] = ...
    CAP_SYS_MODULE: typing.ClassVar[int] = ...
    CAP_SYS_NICE: typing.ClassVar[int] = ...
    CAP_SYS_PACCT: typing.ClassVar[int] = ...
    CAP_SYS_PTRACE: typing.ClassVar[int] = ...
    CAP_SYS_RAWIO: typing.ClassVar[int] = ...
    CAP_SYS_RESOURCE: typing.ClassVar[int] = ...
    CAP_SYS_TIME: typing.ClassVar[int] = ...
    CAP_SYS_TTY_CONFIG: typing.ClassVar[int] = ...
    CAP_WAKE_ALARM: typing.ClassVar[int] = ...
    E2BIG: typing.ClassVar[int] = ...
    EACCES: typing.ClassVar[int] = ...
    EADDRINUSE: typing.ClassVar[int] = ...
    EADDRNOTAVAIL: typing.ClassVar[int] = ...
    EAFNOSUPPORT: typing.ClassVar[int] = ...
    EAGAIN: typing.ClassVar[int] = ...
    EAI_AGAIN: typing.ClassVar[int] = ...
    EAI_BADFLAGS: typing.ClassVar[int] = ...
    EAI_FAIL: typing.ClassVar[int] = ...
    EAI_FAMILY: typing.ClassVar[int] = ...
    EAI_MEMORY: typing.ClassVar[int] = ...
    EAI_NODATA: typing.ClassVar[int] = ...
    EAI_NONAME: typing.ClassVar[int] = ...
    EAI_OVERFLOW: typing.ClassVar[int] = ...
    EAI_SERVICE: typing.ClassVar[int] = ...
    EAI_SOCKTYPE: typing.ClassVar[int] = ...
    EAI_SYSTEM: typing.ClassVar[int] = ...
    EALREADY: typing.ClassVar[int] = ...
    EBADF: typing.ClassVar[int] = ...
    EBADMSG: typing.ClassVar[int] = ...
    EBUSY: typing.ClassVar[int] = ...
    ECANCELED: typing.ClassVar[int] = ...
    ECHILD: typing.ClassVar[int] = ...
    ECONNABORTED: typing.ClassVar[int] = ...
    ECONNREFUSED: typing.ClassVar[int] = ...
    ECONNRESET: typing.ClassVar[int] = ...
    EDEADLK: typing.ClassVar[int] = ...
    EDESTADDRREQ: typing.ClassVar[int] = ...
    EDOM: typing.ClassVar[int] = ...
    EDQUOT: typing.ClassVar[int] = ...
    EEXIST: typing.ClassVar[int] = ...
    EFAULT: typing.ClassVar[int] = ...
    EFBIG: typing.ClassVar[int] = ...
    EHOSTUNREACH: typing.ClassVar[int] = ...
    EIDRM: typing.ClassVar[int] = ...
    EILSEQ: typing.ClassVar[int] = ...
    EINPROGRESS: typing.ClassVar[int] = ...
    EINTR: typing.ClassVar[int] = ...
    EINVAL: typing.ClassVar[int] = ...
    EIO: typing.ClassVar[int] = ...
    EISCONN: typing.ClassVar[int] = ...
    EISDIR: typing.ClassVar[int] = ...
    ELOOP: typing.ClassVar[int] = ...
    EMFILE: typing.ClassVar[int] = ...
    EMLINK: typing.ClassVar[int] = ...
    EMSGSIZE: typing.ClassVar[int] = ...
    EMULTIHOP: typing.ClassVar[int] = ...
    ENAMETOOLONG: typing.ClassVar[int] = ...
    ENETDOWN: typing.ClassVar[int] = ...
    ENETRESET: typing.ClassVar[int] = ...
    ENETUNREACH: typing.ClassVar[int] = ...
    ENFILE: typing.ClassVar[int] = ...
    ENOBUFS: typing.ClassVar[int] = ...
    ENODATA: typing.ClassVar[int] = ...
    ENODEV: typing.ClassVar[int] = ...
    ENOENT: typing.ClassVar[int] = ...
    ENOEXEC: typing.ClassVar[int] = ...
    ENOLCK: typing.ClassVar[int] = ...
    ENOLINK: typing.ClassVar[int] = ...
    ENOMEM: typing.ClassVar[int] = ...
    ENOMSG: typing.ClassVar[int] = ...
    ENONET: typing.ClassVar[int] = ...
    ENOPROTOOPT: typing.ClassVar[int] = ...
    ENOSPC: typing.ClassVar[int] = ...
    ENOSR: typing.ClassVar[int] = ...
    ENOSTR: typing.ClassVar[int] = ...
    ENOSYS: typing.ClassVar[int] = ...
    ENOTCONN: typing.ClassVar[int] = ...
    ENOTDIR: typing.ClassVar[int] = ...
    ENOTEMPTY: typing.ClassVar[int] = ...
    ENOTSOCK: typing.ClassVar[int] = ...
    ENOTSUP: typing.ClassVar[int] = ...
    ENOTTY: typing.ClassVar[int] = ...
    ENXIO: typing.ClassVar[int] = ...
    EOPNOTSUPP: typing.ClassVar[int] = ...
    EOVERFLOW: typing.ClassVar[int] = ...
    EPERM: typing.ClassVar[int] = ...
    EPIPE: typing.ClassVar[int] = ...
    EPROTO: typing.ClassVar[int] = ...
    EPROTONOSUPPORT: typing.ClassVar[int] = ...
    EPROTOTYPE: typing.ClassVar[int] = ...
    ERANGE: typing.ClassVar[int] = ...
    EROFS: typing.ClassVar[int] = ...
    ESPIPE: typing.ClassVar[int] = ...
    ESRCH: typing.ClassVar[int] = ...
    ESTALE: typing.ClassVar[int] = ...
    ETH_P_ALL: typing.ClassVar[int] = ...
    ETH_P_ARP: typing.ClassVar[int] = ...
    ETH_P_IP: typing.ClassVar[int] = ...
    ETH_P_IPV6: typing.ClassVar[int] = ...
    ETIME: typing.ClassVar[int] = ...
    ETIMEDOUT: typing.ClassVar[int] = ...
    ETXTBSY: typing.ClassVar[int] = ...
    EXDEV: typing.ClassVar[int] = ...
    EXIT_FAILURE: typing.ClassVar[int] = ...
    EXIT_SUCCESS: typing.ClassVar[int] = ...
    FD_CLOEXEC: typing.ClassVar[int] = ...
    FIONREAD: typing.ClassVar[int] = ...
    F_DUPFD: typing.ClassVar[int] = ...
    F_DUPFD_CLOEXEC: typing.ClassVar[int] = ...
    F_GETFD: typing.ClassVar[int] = ...
    F_GETFL: typing.ClassVar[int] = ...
    F_GETLK64: typing.ClassVar[int] = ...
    F_GETLK: typing.ClassVar[int] = ...
    F_GETOWN: typing.ClassVar[int] = ...
    F_OK: typing.ClassVar[int] = ...
    F_RDLCK: typing.ClassVar[int] = ...
    F_SETFD: typing.ClassVar[int] = ...
    F_SETFL: typing.ClassVar[int] = ...
    F_SETLK64: typing.ClassVar[int] = ...
    F_SETLK: typing.ClassVar[int] = ...
    F_SETLKW64: typing.ClassVar[int] = ...
    F_SETLKW: typing.ClassVar[int] = ...
    F_SETOWN: typing.ClassVar[int] = ...
    F_UNLCK: typing.ClassVar[int] = ...
    F_WRLCK: typing.ClassVar[int] = ...
    ICMP6_ECHO_REPLY: typing.ClassVar[int] = ...
    ICMP6_ECHO_REQUEST: typing.ClassVar[int] = ...
    ICMP_ECHO: typing.ClassVar[int] = ...
    ICMP_ECHOREPLY: typing.ClassVar[int] = ...
    IFA_F_DADFAILED: typing.ClassVar[int] = ...
    IFA_F_DEPRECATED: typing.ClassVar[int] = ...
    IFA_F_HOMEADDRESS: typing.ClassVar[int] = ...
    IFA_F_MANAGETEMPADDR: typing.ClassVar[int] = ...
    IFA_F_NODAD: typing.ClassVar[int] = ...
    IFA_F_NOPREFIXROUTE: typing.ClassVar[int] = ...
    IFA_F_OPTIMISTIC: typing.ClassVar[int] = ...
    IFA_F_PERMANENT: typing.ClassVar[int] = ...
    IFA_F_SECONDARY: typing.ClassVar[int] = ...
    IFA_F_TEMPORARY: typing.ClassVar[int] = ...
    IFA_F_TENTATIVE: typing.ClassVar[int] = ...
    IFF_ALLMULTI: typing.ClassVar[int] = ...
    IFF_AUTOMEDIA: typing.ClassVar[int] = ...
    IFF_BROADCAST: typing.ClassVar[int] = ...
    IFF_DEBUG: typing.ClassVar[int] = ...
    IFF_DYNAMIC: typing.ClassVar[int] = ...
    IFF_LOOPBACK: typing.ClassVar[int] = ...
    IFF_MASTER: typing.ClassVar[int] = ...
    IFF_MULTICAST: typing.ClassVar[int] = ...
    IFF_NOARP: typing.ClassVar[int] = ...
    IFF_NOTRAILERS: typing.ClassVar[int] = ...
    IFF_POINTOPOINT: typing.ClassVar[int] = ...
    IFF_PORTSEL: typing.ClassVar[int] = ...
    IFF_PROMISC: typing.ClassVar[int] = ...
    IFF_RUNNING: typing.ClassVar[int] = ...
    IFF_SLAVE: typing.ClassVar[int] = ...
    IFF_UP: typing.ClassVar[int] = ...
    IPPROTO_ESP: typing.ClassVar[int] = ...
    IPPROTO_ICMP: typing.ClassVar[int] = ...
    IPPROTO_ICMPV6: typing.ClassVar[int] = ...
    IPPROTO_IP: typing.ClassVar[int] = ...
    IPPROTO_IPV6: typing.ClassVar[int] = ...
    IPPROTO_RAW: typing.ClassVar[int] = ...
    IPPROTO_TCP: typing.ClassVar[int] = ...
    IPPROTO_UDP: typing.ClassVar[int] = ...
    IPV6_CHECKSUM: typing.ClassVar[int] = ...
    IPV6_MULTICAST_HOPS: typing.ClassVar[int] = ...
    IPV6_MULTICAST_IF: typing.ClassVar[int] = ...
    IPV6_MULTICAST_LOOP: typing.ClassVar[int] = ...
    IPV6_PKTINFO: typing.ClassVar[int] = ...
    IPV6_RECVDSTOPTS: typing.ClassVar[int] = ...
    IPV6_RECVHOPLIMIT: typing.ClassVar[int] = ...
    IPV6_RECVHOPOPTS: typing.ClassVar[int] = ...
    IPV6_RECVPKTINFO: typing.ClassVar[int] = ...
    IPV6_RECVRTHDR: typing.ClassVar[int] = ...
    IPV6_RECVTCLASS: typing.ClassVar[int] = ...
    IPV6_TCLASS: typing.ClassVar[int] = ...
    IPV6_UNICAST_HOPS: typing.ClassVar[int] = ...
    IPV6_V6ONLY: typing.ClassVar[int] = ...
    IP_MULTICAST_IF: typing.ClassVar[int] = ...
    IP_MULTICAST_LOOP: typing.ClassVar[int] = ...
    IP_MULTICAST_TTL: typing.ClassVar[int] = ...
    IP_TOS: typing.ClassVar[int] = ...
    IP_TTL: typing.ClassVar[int] = ...
    MAP_ANONYMOUS: typing.ClassVar[int] = ...
    MAP_FIXED: typing.ClassVar[int] = ...
    MAP_PRIVATE: typing.ClassVar[int] = ...
    MAP_SHARED: typing.ClassVar[int] = ...
    MCAST_BLOCK_SOURCE: typing.ClassVar[int] = ...
    MCAST_JOIN_GROUP: typing.ClassVar[int] = ...
    MCAST_JOIN_SOURCE_GROUP: typing.ClassVar[int] = ...
    MCAST_LEAVE_GROUP: typing.ClassVar[int] = ...
    MCAST_LEAVE_SOURCE_GROUP: typing.ClassVar[int] = ...
    MCAST_UNBLOCK_SOURCE: typing.ClassVar[int] = ...
    MCL_CURRENT: typing.ClassVar[int] = ...
    MCL_FUTURE: typing.ClassVar[int] = ...
    MFD_CLOEXEC: typing.ClassVar[int] = ...
    MSG_CTRUNC: typing.ClassVar[int] = ...
    MSG_DONTROUTE: typing.ClassVar[int] = ...
    MSG_EOR: typing.ClassVar[int] = ...
    MSG_OOB: typing.ClassVar[int] = ...
    MSG_PEEK: typing.ClassVar[int] = ...
    MSG_TRUNC: typing.ClassVar[int] = ...
    MSG_WAITALL: typing.ClassVar[int] = ...
    MS_ASYNC: typing.ClassVar[int] = ...
    MS_INVALIDATE: typing.ClassVar[int] = ...
    MS_SYNC: typing.ClassVar[int] = ...
    NETLINK_INET_DIAG: typing.ClassVar[int] = ...
    NETLINK_NETFILTER: typing.ClassVar[int] = ...
    NETLINK_ROUTE: typing.ClassVar[int] = ...
    NETLINK_XFRM: typing.ClassVar[int] = ...
    NI_DGRAM: typing.ClassVar[int] = ...
    NI_NAMEREQD: typing.ClassVar[int] = ...
    NI_NOFQDN: typing.ClassVar[int] = ...
    NI_NUMERICHOST: typing.ClassVar[int] = ...
    NI_NUMERICSERV: typing.ClassVar[int] = ...
    O_ACCMODE: typing.ClassVar[int] = ...
    O_APPEND: typing.ClassVar[int] = ...
    O_CLOEXEC: typing.ClassVar[int] = ...
    O_CREAT: typing.ClassVar[int] = ...
    O_DSYNC: typing.ClassVar[int] = ...
    O_EXCL: typing.ClassVar[int] = ...
    O_NOCTTY: typing.ClassVar[int] = ...
    O_NOFOLLOW: typing.ClassVar[int] = ...
    O_NONBLOCK: typing.ClassVar[int] = ...
    O_RDONLY: typing.ClassVar[int] = ...
    O_RDWR: typing.ClassVar[int] = ...
    O_SYNC: typing.ClassVar[int] = ...
    O_TRUNC: typing.ClassVar[int] = ...
    O_WRONLY: typing.ClassVar[int] = ...
    PACKET_IGNORE_OUTGOING: typing.ClassVar[int] = ...
    POLLERR: typing.ClassVar[int] = ...
    POLLHUP: typing.ClassVar[int] = ...
    POLLIN: typing.ClassVar[int] = ...
    POLLNVAL: typing.ClassVar[int] = ...
    POLLOUT: typing.ClassVar[int] = ...
    POLLPRI: typing.ClassVar[int] = ...
    POLLRDBAND: typing.ClassVar[int] = ...
    POLLRDNORM: typing.ClassVar[int] = ...
    POLLWRBAND: typing.ClassVar[int] = ...
    POLLWRNORM: typing.ClassVar[int] = ...
    PROT_EXEC: typing.ClassVar[int] = ...
    PROT_NONE: typing.ClassVar[int] = ...
    PROT_READ: typing.ClassVar[int] = ...
    PROT_WRITE: typing.ClassVar[int] = ...
    PR_GET_DUMPABLE: typing.ClassVar[int] = ...
    PR_SET_DUMPABLE: typing.ClassVar[int] = ...
    PR_SET_NO_NEW_PRIVS: typing.ClassVar[int] = ...
    RTMGRP_NEIGH: typing.ClassVar[int] = ...
    RT_SCOPE_HOST: typing.ClassVar[int] = ...
    RT_SCOPE_LINK: typing.ClassVar[int] = ...
    RT_SCOPE_NOWHERE: typing.ClassVar[int] = ...
    RT_SCOPE_SITE: typing.ClassVar[int] = ...
    RT_SCOPE_UNIVERSE: typing.ClassVar[int] = ...
    R_OK: typing.ClassVar[int] = ...
    SEEK_CUR: typing.ClassVar[int] = ...
    SEEK_END: typing.ClassVar[int] = ...
    SEEK_SET: typing.ClassVar[int] = ...
    SHUT_RD: typing.ClassVar[int] = ...
    SHUT_RDWR: typing.ClassVar[int] = ...
    SHUT_WR: typing.ClassVar[int] = ...
    SIGABRT: typing.ClassVar[int] = ...
    SIGALRM: typing.ClassVar[int] = ...
    SIGBUS: typing.ClassVar[int] = ...
    SIGCHLD: typing.ClassVar[int] = ...
    SIGCONT: typing.ClassVar[int] = ...
    SIGFPE: typing.ClassVar[int] = ...
    SIGHUP: typing.ClassVar[int] = ...
    SIGILL: typing.ClassVar[int] = ...
    SIGINT: typing.ClassVar[int] = ...
    SIGIO: typing.ClassVar[int] = ...
    SIGKILL: typing.ClassVar[int] = ...
    SIGPIPE: typing.ClassVar[int] = ...
    SIGPROF: typing.ClassVar[int] = ...
    SIGPWR: typing.ClassVar[int] = ...
    SIGQUIT: typing.ClassVar[int] = ...
    SIGRTMAX: typing.ClassVar[int] = ...
    SIGRTMIN: typing.ClassVar[int] = ...
    SIGSEGV: typing.ClassVar[int] = ...
    SIGSTKFLT: typing.ClassVar[int] = ...
    SIGSTOP: typing.ClassVar[int] = ...
    SIGSYS: typing.ClassVar[int] = ...
    SIGTERM: typing.ClassVar[int] = ...
    SIGTRAP: typing.ClassVar[int] = ...
    SIGTSTP: typing.ClassVar[int] = ...
    SIGTTIN: typing.ClassVar[int] = ...
    SIGTTOU: typing.ClassVar[int] = ...
    SIGURG: typing.ClassVar[int] = ...
    SIGUSR1: typing.ClassVar[int] = ...
    SIGUSR2: typing.ClassVar[int] = ...
    SIGVTALRM: typing.ClassVar[int] = ...
    SIGWINCH: typing.ClassVar[int] = ...
    SIGXCPU: typing.ClassVar[int] = ...
    SIGXFSZ: typing.ClassVar[int] = ...
    SIOCGIFADDR: typing.ClassVar[int] = ...
    SIOCGIFBRDADDR: typing.ClassVar[int] = ...
    SIOCGIFDSTADDR: typing.ClassVar[int] = ...
    SIOCGIFNETMASK: typing.ClassVar[int] = ...
    SOCK_CLOEXEC: typing.ClassVar[int] = ...
    SOCK_DGRAM: typing.ClassVar[int] = ...
    SOCK_NONBLOCK: typing.ClassVar[int] = ...
    SOCK_RAW: typing.ClassVar[int] = ...
    SOCK_SEQPACKET: typing.ClassVar[int] = ...
    SOCK_STREAM: typing.ClassVar[int] = ...
    SOL_PACKET: typing.ClassVar[int] = ...
    SOL_SOCKET: typing.ClassVar[int] = ...
    SOL_UDP: typing.ClassVar[int] = ...
    SO_BINDTODEVICE: typing.ClassVar[int] = ...
    SO_BROADCAST: typing.ClassVar[int] = ...
    SO_DEBUG: typing.ClassVar[int] = ...
    SO_DONTROUTE: typing.ClassVar[int] = ...
    SO_ERROR: typing.ClassVar[int] = ...
    SO_KEEPALIVE: typing.ClassVar[int] = ...
    SO_LINGER: typing.ClassVar[int] = ...
    SO_OOBINLINE: typing.ClassVar[int] = ...
    SO_PASSCRED: typing.ClassVar[int] = ...
    SO_PEERCRED: typing.ClassVar[int] = ...
    SO_RCVBUF: typing.ClassVar[int] = ...
    SO_RCVLOWAT: typing.ClassVar[int] = ...
    SO_RCVTIMEO: typing.ClassVar[int] = ...
    SO_REUSEADDR: typing.ClassVar[int] = ...
    SO_SNDBUF: typing.ClassVar[int] = ...
    SO_SNDLOWAT: typing.ClassVar[int] = ...
    SO_SNDTIMEO: typing.ClassVar[int] = ...
    SO_TYPE: typing.ClassVar[int] = ...
    STDERR_FILENO: typing.ClassVar[int] = ...
    STDIN_FILENO: typing.ClassVar[int] = ...
    STDOUT_FILENO: typing.ClassVar[int] = ...
    ST_MANDLOCK: typing.ClassVar[int] = ...
    ST_NOATIME: typing.ClassVar[int] = ...
    ST_NODEV: typing.ClassVar[int] = ...
    ST_NODIRATIME: typing.ClassVar[int] = ...
    ST_NOEXEC: typing.ClassVar[int] = ...
    ST_NOSUID: typing.ClassVar[int] = ...
    ST_RDONLY: typing.ClassVar[int] = ...
    ST_RELATIME: typing.ClassVar[int] = ...
    ST_SYNCHRONOUS: typing.ClassVar[int] = ...
    S_IFBLK: typing.ClassVar[int] = ...
    S_IFCHR: typing.ClassVar[int] = ...
    S_IFDIR: typing.ClassVar[int] = ...
    S_IFIFO: typing.ClassVar[int] = ...
    S_IFLNK: typing.ClassVar[int] = ...
    S_IFMT: typing.ClassVar[int] = ...
    S_IFREG: typing.ClassVar[int] = ...
    S_IFSOCK: typing.ClassVar[int] = ...
    S_IRGRP: typing.ClassVar[int] = ...
    S_IROTH: typing.ClassVar[int] = ...
    S_IRUSR: typing.ClassVar[int] = ...
    S_IRWXG: typing.ClassVar[int] = ...
    S_IRWXO: typing.ClassVar[int] = ...
    S_IRWXU: typing.ClassVar[int] = ...
    S_ISGID: typing.ClassVar[int] = ...
    S_ISUID: typing.ClassVar[int] = ...
    S_ISVTX: typing.ClassVar[int] = ...
    S_IWGRP: typing.ClassVar[int] = ...
    S_IWOTH: typing.ClassVar[int] = ...
    S_IWUSR: typing.ClassVar[int] = ...
    S_IXGRP: typing.ClassVar[int] = ...
    S_IXOTH: typing.ClassVar[int] = ...
    S_IXUSR: typing.ClassVar[int] = ...
    TCP_NODELAY: typing.ClassVar[int] = ...
    TCP_USER_TIMEOUT: typing.ClassVar[int] = ...
    UDP_GRO: typing.ClassVar[int] = ...
    UDP_SEGMENT: typing.ClassVar[int] = ...
    VMADDR_CID_ANY: typing.ClassVar[int] = ...
    VMADDR_CID_HOST: typing.ClassVar[int] = ...
    VMADDR_CID_LOCAL: typing.ClassVar[int] = ...
    VMADDR_PORT_ANY: typing.ClassVar[int] = ...
    WCONTINUED: typing.ClassVar[int] = ...
    WEXITED: typing.ClassVar[int] = ...
    WNOHANG: typing.ClassVar[int] = ...
    WNOWAIT: typing.ClassVar[int] = ...
    WSTOPPED: typing.ClassVar[int] = ...
    WUNTRACED: typing.ClassVar[int] = ...
    W_OK: typing.ClassVar[int] = ...
    X_OK: typing.ClassVar[int] = ...
    _SC_2_CHAR_TERM: typing.ClassVar[int] = ...
    _SC_2_C_BIND: typing.ClassVar[int] = ...
    _SC_2_C_DEV: typing.ClassVar[int] = ...
    _SC_2_C_VERSION: typing.ClassVar[int] = ...
    _SC_2_FORT_DEV: typing.ClassVar[int] = ...
    _SC_2_FORT_RUN: typing.ClassVar[int] = ...
    _SC_2_LOCALEDEF: typing.ClassVar[int] = ...
    _SC_2_SW_DEV: typing.ClassVar[int] = ...
    _SC_2_UPE: typing.ClassVar[int] = ...
    _SC_2_VERSION: typing.ClassVar[int] = ...
    _SC_AIO_LISTIO_MAX: typing.ClassVar[int] = ...
    _SC_AIO_MAX: typing.ClassVar[int] = ...
    _SC_AIO_PRIO_DELTA_MAX: typing.ClassVar[int] = ...
    _SC_ARG_MAX: typing.ClassVar[int] = ...
    _SC_ASYNCHRONOUS_IO: typing.ClassVar[int] = ...
    _SC_ATEXIT_MAX: typing.ClassVar[int] = ...
    _SC_AVPHYS_PAGES: typing.ClassVar[int] = ...
    _SC_BC_BASE_MAX: typing.ClassVar[int] = ...
    _SC_BC_DIM_MAX: typing.ClassVar[int] = ...
    _SC_BC_SCALE_MAX: typing.ClassVar[int] = ...
    _SC_BC_STRING_MAX: typing.ClassVar[int] = ...
    _SC_CHILD_MAX: typing.ClassVar[int] = ...
    _SC_CLK_TCK: typing.ClassVar[int] = ...
    _SC_COLL_WEIGHTS_MAX: typing.ClassVar[int] = ...
    _SC_DELAYTIMER_MAX: typing.ClassVar[int] = ...
    _SC_EXPR_NEST_MAX: typing.ClassVar[int] = ...
    _SC_FSYNC: typing.ClassVar[int] = ...
    _SC_GETGR_R_SIZE_MAX: typing.ClassVar[int] = ...
    _SC_GETPW_R_SIZE_MAX: typing.ClassVar[int] = ...
    _SC_IOV_MAX: typing.ClassVar[int] = ...
    _SC_JOB_CONTROL: typing.ClassVar[int] = ...
    _SC_LINE_MAX: typing.ClassVar[int] = ...
    _SC_LOGIN_NAME_MAX: typing.ClassVar[int] = ...
    _SC_MAPPED_FILES: typing.ClassVar[int] = ...
    _SC_MEMLOCK: typing.ClassVar[int] = ...
    _SC_MEMLOCK_RANGE: typing.ClassVar[int] = ...
    _SC_MEMORY_PROTECTION: typing.ClassVar[int] = ...
    _SC_MESSAGE_PASSING: typing.ClassVar[int] = ...
    _SC_MQ_OPEN_MAX: typing.ClassVar[int] = ...
    _SC_MQ_PRIO_MAX: typing.ClassVar[int] = ...
    _SC_NGROUPS_MAX: typing.ClassVar[int] = ...
    _SC_NPROCESSORS_CONF: typing.ClassVar[int] = ...
    _SC_NPROCESSORS_ONLN: typing.ClassVar[int] = ...
    _SC_OPEN_MAX: typing.ClassVar[int] = ...
    _SC_PAGESIZE: typing.ClassVar[int] = ...
    _SC_PAGE_SIZE: typing.ClassVar[int] = ...
    _SC_PASS_MAX: typing.ClassVar[int] = ...
    _SC_PHYS_PAGES: typing.ClassVar[int] = ...
    _SC_PRIORITIZED_IO: typing.ClassVar[int] = ...
    _SC_PRIORITY_SCHEDULING: typing.ClassVar[int] = ...
    _SC_REALTIME_SIGNALS: typing.ClassVar[int] = ...
    _SC_RE_DUP_MAX: typing.ClassVar[int] = ...
    _SC_RTSIG_MAX: typing.ClassVar[int] = ...
    _SC_SAVED_IDS: typing.ClassVar[int] = ...
    _SC_SEMAPHORES: typing.ClassVar[int] = ...
    _SC_SEM_NSEMS_MAX: typing.ClassVar[int] = ...
    _SC_SEM_VALUE_MAX: typing.ClassVar[int] = ...
    _SC_SHARED_MEMORY_OBJECTS: typing.ClassVar[int] = ...
    _SC_SIGQUEUE_MAX: typing.ClassVar[int] = ...
    _SC_STREAM_MAX: typing.ClassVar[int] = ...
    _SC_SYNCHRONIZED_IO: typing.ClassVar[int] = ...
    _SC_THREADS: typing.ClassVar[int] = ...
    _SC_THREAD_ATTR_STACKADDR: typing.ClassVar[int] = ...
    _SC_THREAD_ATTR_STACKSIZE: typing.ClassVar[int] = ...
    _SC_THREAD_DESTRUCTOR_ITERATIONS: typing.ClassVar[int] = ...
    _SC_THREAD_KEYS_MAX: typing.ClassVar[int] = ...
    _SC_THREAD_PRIORITY_SCHEDULING: typing.ClassVar[int] = ...
    _SC_THREAD_PRIO_INHERIT: typing.ClassVar[int] = ...
    _SC_THREAD_PRIO_PROTECT: typing.ClassVar[int] = ...
    _SC_THREAD_SAFE_FUNCTIONS: typing.ClassVar[int] = ...
    _SC_THREAD_STACK_MIN: typing.ClassVar[int] = ...
    _SC_THREAD_THREADS_MAX: typing.ClassVar[int] = ...
    _SC_TIMERS: typing.ClassVar[int] = ...
    _SC_TIMER_MAX: typing.ClassVar[int] = ...
    _SC_TTY_NAME_MAX: typing.ClassVar[int] = ...
    _SC_TZNAME_MAX: typing.ClassVar[int] = ...
    _SC_VERSION: typing.ClassVar[int] = ...
    _SC_XBS5_ILP32_OFF32: typing.ClassVar[int] = ...
    _SC_XBS5_ILP32_OFFBIG: typing.ClassVar[int] = ...
    _SC_XBS5_LP64_OFF64: typing.ClassVar[int] = ...
    _SC_XBS5_LPBIG_OFFBIG: typing.ClassVar[int] = ...
    _SC_XOPEN_CRYPT: typing.ClassVar[int] = ...
    _SC_XOPEN_ENH_I18N: typing.ClassVar[int] = ...
    _SC_XOPEN_LEGACY: typing.ClassVar[int] = ...
    _SC_XOPEN_REALTIME: typing.ClassVar[int] = ...
    _SC_XOPEN_REALTIME_THREADS: typing.ClassVar[int] = ...
    _SC_XOPEN_SHM: typing.ClassVar[int] = ...
    _SC_XOPEN_UNIX: typing.ClassVar[int] = ...
    _SC_XOPEN_VERSION: typing.ClassVar[int] = ...
    _SC_XOPEN_XCU_VERSION: typing.ClassVar[int] = ...
    @staticmethod
    def S_ISBLK(mode: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def S_ISCHR(mode: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def S_ISDIR(mode: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def S_ISFIFO(mode: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def S_ISLNK(mode: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def S_ISREG(mode: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def S_ISSOCK(mode: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def WCOREDUMP(status: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def WEXITSTATUS(status: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def WIFEXITED(status: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def WIFSIGNALED(status: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def WIFSTOPPED(status: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def WSTOPSIG(status: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def WTERMSIG(status: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def errnoName(errno: int | java.jint | java.lang.Integer, /) -> str: ...
    @staticmethod
    def gaiName(error: int | java.jint | java.lang.Integer, /) -> str: ...

class StructCmsghdr(java.lang.Object):
    cmsg_data: java.chaquopy.JavaArrayJByte = ...
    cmsg_level: int = ...
    cmsg_type: int = ...
    @typing.overload
    def __init__(self, cmsg_level: int | java.jint | java.lang.Integer, cmsg_type: int | java.jint | java.lang.Integer, value: int | java.jshort | java.lang.Short, /) -> None: ...
    @typing.overload
    def __init__(self, cmsg_level: int | java.jint | java.lang.Integer, cmsg_type: int | java.jint | java.lang.Integer, value: java.chaquopy.JavaArrayJByte, /) -> None: ...

class StructMsghdr(java.lang.Object):
    msg_control: java.chaquopy.JavaArray[StructCmsghdr] = ...
    msg_flags: int = ...
    msg_iov: java.chaquopy.JavaArray[java.nio.ByteBuffer] = ...
    msg_name: java.net.SocketAddress = ...
    def __init__(self, msg_name: java.net.SocketAddress, msg_iov: java.chaquopy.JavaArray[java.nio.ByteBuffer], msg_control: java.chaquopy.JavaArray[StructCmsghdr], msg_flags: int | java.jint | java.lang.Integer, /) -> None: ...

class StructPollfd(java.lang.Object):
    events: int = ...
    fd: java.io.FileDescriptor = ...
    revents: int = ...
    userData: java.lang.Object = ...
    def __init__(self) -> None: ...
    def toString(self) -> str: ...

class StructStat(java.lang.Object):
    st_atim: StructTimespec = ...
    st_atime: int = ...
    st_blksize: int = ...
    st_blocks: int = ...
    st_ctim: StructTimespec = ...
    st_ctime: int = ...
    st_dev: int = ...
    st_gid: int = ...
    st_ino: int = ...
    st_mode: int = ...
    st_mtim: StructTimespec = ...
    st_mtime: int = ...
    st_nlink: int = ...
    st_rdev: int = ...
    st_size: int = ...
    st_uid: int = ...
    @typing.overload
    def __init__(self, st_dev: int | java.jlong | java.lang.Long, st_ino: int | java.jlong | java.lang.Long, st_mode: int | java.jint | java.lang.Integer, st_nlink: int | java.jlong | java.lang.Long, st_uid: int | java.jint | java.lang.Integer, st_gid: int | java.jint | java.lang.Integer, st_rdev: int | java.jlong | java.lang.Long, st_size: int | java.jlong | java.lang.Long, st_atime: int | java.jlong | java.lang.Long, st_mtime: int | java.jlong | java.lang.Long, st_ctime: int | java.jlong | java.lang.Long, st_blksize: int | java.jlong | java.lang.Long, st_blocks: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def __init__(self, st_dev: int | java.jlong | java.lang.Long, st_ino: int | java.jlong | java.lang.Long, st_mode: int | java.jint | java.lang.Integer, st_nlink: int | java.jlong | java.lang.Long, st_uid: int | java.jint | java.lang.Integer, st_gid: int | java.jint | java.lang.Integer, st_rdev: int | java.jlong | java.lang.Long, st_size: int | java.jlong | java.lang.Long, st_atim: StructTimespec, st_mtim: StructTimespec, st_ctim: StructTimespec, st_blksize: int | java.jlong | java.lang.Long, st_blocks: int | java.jlong | java.lang.Long, /) -> None: ...
    def toString(self) -> str: ...

class StructStatVfs(java.lang.Object):
    f_bavail: int = ...
    f_bfree: int = ...
    f_blocks: int = ...
    f_bsize: int = ...
    f_favail: int = ...
    f_ffree: int = ...
    f_files: int = ...
    f_flag: int = ...
    f_frsize: int = ...
    f_fsid: int = ...
    f_namemax: int = ...
    def __init__(self, f_bsize: int | java.jlong | java.lang.Long, f_frsize: int | java.jlong | java.lang.Long, f_blocks: int | java.jlong | java.lang.Long, f_bfree: int | java.jlong | java.lang.Long, f_bavail: int | java.jlong | java.lang.Long, f_files: int | java.jlong | java.lang.Long, f_ffree: int | java.jlong | java.lang.Long, f_favail: int | java.jlong | java.lang.Long, f_fsid: int | java.jlong | java.lang.Long, f_flag: int | java.jlong | java.lang.Long, f_namemax: int | java.jlong | java.lang.Long, /) -> None: ...
    def toString(self) -> str: ...

class StructTimespec(java.lang.Comparable[StructTimespec]):
    tv_nsec: int = ...
    tv_sec: int = ...
    def __init__(self, tv_sec: int | java.jlong | java.lang.Long, tv_nsec: int | java.jlong | java.lang.Long, /) -> None: ...
    def compareTo(self, other: StructTimespec, /) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class StructTimeval(java.lang.Object):
    tv_sec: int = ...
    tv_usec: int = ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def fromMillis(millis: int | java.jlong | java.lang.Long, /) -> StructTimeval: ...
    def hashCode(self) -> int: ...
    def toMillis(self) -> int: ...
    def toString(self) -> str: ...

class StructUtsname(java.lang.Object):
    machine: str = ...
    nodename: str = ...
    release: str = ...
    sysname: str = ...
    version: str = ...
    def __init__(self, sysname: str | java.lang.String, nodename: str | java.lang.String, release: str | java.lang.String, version: str | java.lang.String, machine: str | java.lang.String, /) -> None: ...
    def toString(self) -> str: ...

class SystemCleaner(java.lang.Object):
    @staticmethod
    def cleaner() -> java.lang.ref.Cleaner: ...

class VmSocketAddress(java.net.SocketAddress):
    def __init__(self, svmPort: int | java.jint | java.lang.Integer, svmCid: int | java.jint | java.lang.Integer, /) -> None: ...
    def getSvmCid(self) -> int: ...
    def getSvmPort(self) -> int: ...



import typing

import java
import java.chaquopy
import java.io
import java.lang
import java.lang.reflect
import java.nio
import java.util

class CallSite(java.lang.Object):
    def dynamicInvoker(self) -> MethodHandle: ...
    def getTarget(self) -> MethodHandle: ...
    def setTarget(self, arg1: MethodHandle, /) -> None: ...
    def type(self) -> MethodType: ...

class ConstantCallSite(CallSite):
    @typing.overload
    def __init__(self, target: MethodHandle, /) -> None: ...
    @typing.overload
    def __init__(self, targetType: MethodType, createTargetHook: MethodHandle, /) -> None: ...
    def dynamicInvoker(self) -> MethodHandle: ...
    def getTarget(self) -> MethodHandle: ...
    def setTarget(self, ignore: MethodHandle, /) -> None: ...

class LambdaConversionException(java.lang.Exception):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, cause: java.lang.Throwable, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, cause: java.lang.Throwable, enableSuppression: bool | java.jboolean | java.lang.Boolean, writableStackTrace: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

class MethodHandle(java.lang.Object):
    @typing.overload
    def asCollector(self, arrayType: typing.Type[java.lang.Object], arrayLength: int | java.jint | java.lang.Integer, /) -> MethodHandle: ...
    @typing.overload
    def asCollector(self, collectArgPos: int | java.jint | java.lang.Integer, arrayType: typing.Type[java.lang.Object], arrayLength: int | java.jint | java.lang.Integer, /) -> MethodHandle: ...
    def asFixedArity(self) -> MethodHandle: ...
    @typing.overload
    def asSpreader(self, arrayType: typing.Type[java.lang.Object], arrayLength: int | java.jint | java.lang.Integer, /) -> MethodHandle: ...
    @typing.overload
    def asSpreader(self, spreadArgPos: int | java.jint | java.lang.Integer, arrayType: typing.Type[java.lang.Object], arrayLength: int | java.jint | java.lang.Integer, /) -> MethodHandle: ...
    def asType(self, newType: MethodType, /) -> MethodHandle: ...
    def asVarargsCollector(self, arrayType: typing.Type[java.lang.Object], /) -> MethodHandle: ...
    def bindTo(self, x: java.lang.Object | int | bool | float | str, /) -> MethodHandle: ...
    def invoke(self, *arg1: java.lang.Object) -> java.lang.Object: ...
    def invokeExact(self, *arg1: java.lang.Object) -> java.lang.Object: ...
    @typing.overload
    def invokeWithArguments(self, arguments: java.util.List[java.lang.Object], /) -> java.lang.Object: ...
    @typing.overload
    def invokeWithArguments(self, *arguments: java.lang.Object) -> java.lang.Object: ...
    def isVarargsCollector(self) -> bool: ...
    def toString(self) -> str: ...
    def type(self) -> MethodType: ...
    def withVarargs(self, makeVarargs: bool | java.jboolean | java.lang.Boolean, /) -> MethodHandle: ...

class MethodHandleInfo(java.lang.Object):
    REF_getField: typing.ClassVar[int] = ...
    REF_getStatic: typing.ClassVar[int] = ...
    REF_invokeInterface: typing.ClassVar[int] = ...
    REF_invokeSpecial: typing.ClassVar[int] = ...
    REF_invokeStatic: typing.ClassVar[int] = ...
    REF_invokeVirtual: typing.ClassVar[int] = ...
    REF_newInvokeSpecial: typing.ClassVar[int] = ...
    REF_putField: typing.ClassVar[int] = ...
    REF_putStatic: typing.ClassVar[int] = ...
    def getDeclaringClass(self) -> typing.Type[java.lang.Object]: ...
    def getMethodType(self) -> MethodType: ...
    def getModifiers(self) -> int: ...
    def getName(self) -> str: ...
    def getReferenceKind(self) -> int: ...
    def isVarArgs(self) -> bool: ...
    @staticmethod
    def refKindIsField(refKind: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def refKindIsValid(refKind: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def refKindName(refKind: int | java.jint | java.lang.Integer, /) -> str: ...
    @staticmethod
    def referenceKindToString(referenceKind: int | java.jint | java.lang.Integer, /) -> str: ...
    _reflectAs__T = typing.TypeVar('_reflectAs__T')  # <T>
    def reflectAs(self, arg1: typing.Type[_reflectAs__T], arg2: MethodHandles.Lookup, /) -> _reflectAs__T: ...
    @staticmethod
    def toString(kind: int | java.jint | java.lang.Integer, defc: typing.Type[java.lang.Object], name: str | java.lang.String, type: MethodType, /) -> str: ...

class MethodHandles(java.lang.Object):
    @staticmethod
    def arrayConstructor(arrayClass: typing.Type[java.lang.Object], /) -> MethodHandle: ...
    @staticmethod
    def arrayElementGetter(arrayClass: typing.Type[java.lang.Object], /) -> MethodHandle: ...
    @staticmethod
    def arrayElementSetter(arrayClass: typing.Type[java.lang.Object], /) -> MethodHandle: ...
    @staticmethod
    def arrayElementVarHandle(arrayClass: typing.Type[java.lang.Object], /) -> VarHandle: ...
    @staticmethod
    def arrayLength(arrayClass: typing.Type[java.lang.Object], /) -> MethodHandle: ...
    @staticmethod
    def byteArrayViewVarHandle(viewArrayClass: typing.Type[java.lang.Object], byteOrder: java.nio.ByteOrder, /) -> VarHandle: ...
    @staticmethod
    def byteBufferViewVarHandle(viewArrayClass: typing.Type[java.lang.Object], byteOrder: java.nio.ByteOrder, /) -> VarHandle: ...
    @staticmethod
    def catchException(target: MethodHandle, exType: typing.Type[java.lang.Throwable], handler: MethodHandle, /) -> MethodHandle: ...
    @staticmethod
    def collectArguments(target: MethodHandle, pos: int | java.jint | java.lang.Integer, filter: MethodHandle, /) -> MethodHandle: ...
    @staticmethod
    def constant(type: typing.Type[java.lang.Object], value: java.lang.Object | int | bool | float | str, /) -> MethodHandle: ...
    @typing.overload
    @staticmethod
    def countedLoop(iterations: MethodHandle, init: MethodHandle, body: MethodHandle, /) -> MethodHandle: ...
    @typing.overload
    @staticmethod
    def countedLoop(start: MethodHandle, end: MethodHandle, init: MethodHandle, body: MethodHandle, /) -> MethodHandle: ...
    @staticmethod
    def doWhileLoop(init: MethodHandle, body: MethodHandle, pred: MethodHandle, /) -> MethodHandle: ...
    @typing.overload
    @staticmethod
    def dropArguments(target: MethodHandle, pos: int | java.jint | java.lang.Integer, valueTypes: java.util.List[typing.Type[java.lang.Object]], /) -> MethodHandle: ...
    @typing.overload
    @staticmethod
    def dropArguments(target: MethodHandle, pos: int | java.jint | java.lang.Integer, /, *valueTypes: typing.Type[java.lang.Object]) -> MethodHandle: ...
    @staticmethod
    def dropArgumentsToMatch(target: MethodHandle, skip: int | java.jint | java.lang.Integer, newTypes: java.util.List[typing.Type[java.lang.Object]], pos: int | java.jint | java.lang.Integer, /) -> MethodHandle: ...
    @staticmethod
    def dropReturn(target: MethodHandle, /) -> MethodHandle: ...
    @staticmethod
    def empty(type: MethodType, /) -> MethodHandle: ...
    @staticmethod
    def exactInvoker(type: MethodType, /) -> MethodHandle: ...
    @staticmethod
    def explicitCastArguments(target: MethodHandle, newType: MethodType, /) -> MethodHandle: ...
    @staticmethod
    def filterArguments(target: MethodHandle, pos: int | java.jint | java.lang.Integer, /, *filters: MethodHandle) -> MethodHandle: ...
    @staticmethod
    def filterReturnValue(target: MethodHandle, filter: MethodHandle, /) -> MethodHandle: ...
    @typing.overload
    @staticmethod
    def foldArguments(target: MethodHandle, combiner: MethodHandle, /) -> MethodHandle: ...
    @typing.overload
    @staticmethod
    def foldArguments(target: MethodHandle, pos: int | java.jint | java.lang.Integer, combiner: MethodHandle, /) -> MethodHandle: ...
    @staticmethod
    def guardWithTest(test: MethodHandle, target: MethodHandle, fallback: MethodHandle, /) -> MethodHandle: ...
    @staticmethod
    def identity(type: typing.Type[java.lang.Object], /) -> MethodHandle: ...
    @staticmethod
    def insertArguments(target: MethodHandle, pos: int | java.jint | java.lang.Integer, /, *values: java.lang.Object) -> MethodHandle: ...
    @staticmethod
    def invoker(type: MethodType, /) -> MethodHandle: ...
    @staticmethod
    def iteratedLoop(iterator: MethodHandle, init: MethodHandle, body: MethodHandle, /) -> MethodHandle: ...
    @staticmethod
    def lookup() -> MethodHandles.Lookup: ...
    @staticmethod
    def loop(*clauses: java.chaquopy.JavaArray[MethodHandle]) -> MethodHandle: ...
    @staticmethod
    def permuteArguments(target: MethodHandle, newType: MethodType, /, *reorder: java.jint) -> MethodHandle: ...
    @staticmethod
    def privateLookupIn(targetClass: typing.Type[java.lang.Object], lookup: MethodHandles.Lookup, /) -> MethodHandles.Lookup: ...
    @staticmethod
    def publicLookup() -> MethodHandles.Lookup: ...
    _reflectAs__T = typing.TypeVar('_reflectAs__T')  # <T>
    @staticmethod
    def reflectAs(expected: typing.Type[_reflectAs__T], target: MethodHandle, /) -> _reflectAs__T: ...
    @staticmethod
    def spreadInvoker(type: MethodType, leadingArgCount: int | java.jint | java.lang.Integer, /) -> MethodHandle: ...
    @staticmethod
    def tableSwitch(fallback: MethodHandle, /, *targets: MethodHandle) -> MethodHandle: ...
    @staticmethod
    def throwException(returnType: typing.Type[java.lang.Object], exType: typing.Type[java.lang.Throwable], /) -> MethodHandle: ...
    @staticmethod
    def tryFinally(target: MethodHandle, cleanup: MethodHandle, /) -> MethodHandle: ...
    @staticmethod
    def varHandleExactInvoker(accessMode: VarHandle.AccessMode, type: MethodType, /) -> MethodHandle: ...
    @staticmethod
    def varHandleInvoker(accessMode: VarHandle.AccessMode, type: MethodType, /) -> MethodHandle: ...
    @staticmethod
    def whileLoop(init: MethodHandle, pred: MethodHandle, body: MethodHandle, /) -> MethodHandle: ...
    @staticmethod
    def zero(type: typing.Type[java.lang.Object], /) -> MethodHandle: ...

    class Lookup(java.lang.Object):
        PACKAGE: typing.ClassVar[int] = ...
        PRIVATE: typing.ClassVar[int] = ...
        PROTECTED: typing.ClassVar[int] = ...
        PUBLIC: typing.ClassVar[int] = ...
        def bind(self, receiver: java.lang.Object | int | bool | float | str, name: str | java.lang.String, type: MethodType, /) -> MethodHandle: ...
        def findConstructor(self, refc: typing.Type[java.lang.Object], type: MethodType, /) -> MethodHandle: ...
        def findGetter(self, refc: typing.Type[java.lang.Object], name: str | java.lang.String, type: typing.Type[java.lang.Object], /) -> MethodHandle: ...
        def findSetter(self, refc: typing.Type[java.lang.Object], name: str | java.lang.String, type: typing.Type[java.lang.Object], /) -> MethodHandle: ...
        def findSpecial(self, refc: typing.Type[java.lang.Object], name: str | java.lang.String, type: MethodType, specialCaller: typing.Type[java.lang.Object], /) -> MethodHandle: ...
        def findStatic(self, refc: typing.Type[java.lang.Object], name: str | java.lang.String, type: MethodType, /) -> MethodHandle: ...
        def findStaticGetter(self, refc: typing.Type[java.lang.Object], name: str | java.lang.String, type: typing.Type[java.lang.Object], /) -> MethodHandle: ...
        def findStaticSetter(self, refc: typing.Type[java.lang.Object], name: str | java.lang.String, type: typing.Type[java.lang.Object], /) -> MethodHandle: ...
        def findStaticVarHandle(self, decl: typing.Type[java.lang.Object], name: str | java.lang.String, type: typing.Type[java.lang.Object], /) -> VarHandle: ...
        def findVarHandle(self, recv: typing.Type[java.lang.Object], name: str | java.lang.String, type: typing.Type[java.lang.Object], /) -> VarHandle: ...
        def findVirtual(self, refc: typing.Type[java.lang.Object], name: str | java.lang.String, type: MethodType, /) -> MethodHandle: ...
        def in_(self, requestedLookupClass: typing.Type[java.lang.Object], /) -> MethodHandles.Lookup: ...
        def lookupClass(self) -> typing.Type[java.lang.Object]: ...
        def lookupModes(self) -> int: ...
        def revealDirect(self, target: MethodHandle, /) -> MethodHandleInfo: ...
        def toString(self) -> str: ...
        def unreflect(self, m: java.lang.reflect.Method, /) -> MethodHandle: ...
        def unreflectConstructor(self, c: java.lang.reflect.Constructor[java.lang.Object], /) -> MethodHandle: ...
        def unreflectGetter(self, f: java.lang.reflect.Field, /) -> MethodHandle: ...
        def unreflectSetter(self, f: java.lang.reflect.Field, /) -> MethodHandle: ...
        def unreflectSpecial(self, m: java.lang.reflect.Method, specialCaller: typing.Type[java.lang.Object], /) -> MethodHandle: ...
        def unreflectVarHandle(self, f: java.lang.reflect.Field, /) -> VarHandle: ...

class MethodType(TypeDescriptor.OfMethod[typing.Type[java.lang.Object], MethodType], java.io.Serializable):
    @typing.overload
    def appendParameterTypes(self, ptypesToInsert: java.util.List[typing.Type[java.lang.Object]], /) -> MethodType: ...
    @typing.overload
    def appendParameterTypes(self, *ptypesToInsert: typing.Type[java.lang.Object]) -> MethodType: ...
    def changeParameterType(self, num: int | java.jint | java.lang.Integer, nptype: typing.Type[java.lang.Object], /) -> MethodType: ...
    def changeReturnType(self, nrtype: typing.Type[java.lang.Object], /) -> MethodType: ...
    def descriptorString(self) -> str: ...
    def dropParameterTypes(self, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> MethodType: ...
    def equals(self, x: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def erase(self) -> MethodType: ...
    @staticmethod
    def fromMethodDescriptorString(descriptor: str | java.lang.String, loader: java.lang.ClassLoader, /) -> MethodType: ...
    def generic(self) -> MethodType: ...
    @typing.overload
    @staticmethod
    def genericMethodType(objectArgCount: int | java.jint | java.lang.Integer, /) -> MethodType: ...
    @typing.overload
    @staticmethod
    def genericMethodType(objectArgCount: int | java.jint | java.lang.Integer, finalArray: bool | java.jboolean | java.lang.Boolean, /) -> MethodType: ...
    def hasPrimitives(self) -> bool: ...
    def hasWrappers(self) -> bool: ...
    def hashCode(self) -> int: ...
    @typing.overload
    def insertParameterTypes(self, num: int | java.jint | java.lang.Integer, ptypesToInsert: java.util.List[typing.Type[java.lang.Object]], /) -> MethodType: ...
    @typing.overload
    def insertParameterTypes(self, num: int | java.jint | java.lang.Integer, /, *ptypesToInsert: typing.Type[java.lang.Object]) -> MethodType: ...
    def lastParameterType(self) -> typing.Type[java.lang.Object]: ...
    @typing.overload
    @staticmethod
    def methodType(rtype: typing.Type[java.lang.Object], /) -> MethodType: ...
    @typing.overload
    @staticmethod
    def methodType(rtype: typing.Type[java.lang.Object], ptype0: typing.Type[java.lang.Object], /) -> MethodType: ...
    @typing.overload
    @staticmethod
    def methodType(rtype: typing.Type[java.lang.Object], ptypes: MethodType, /) -> MethodType: ...
    @typing.overload
    @staticmethod
    def methodType(rtype: typing.Type[java.lang.Object], ptypes: java.util.List[typing.Type[java.lang.Object]], /) -> MethodType: ...
    @typing.overload
    @staticmethod
    def methodType(rtype: typing.Type[java.lang.Object], ptypes: java.chaquopy.JavaArray[typing.Type[java.lang.Object]], /) -> MethodType: ...
    @typing.overload
    @staticmethod
    def methodType(rtype: typing.Type[java.lang.Object], ptype0: typing.Type[java.lang.Object], /, *ptypes: typing.Type[java.lang.Object]) -> MethodType: ...
    def parameterArray(self) -> java.chaquopy.JavaArray[typing.Type[java.lang.Object]]: ...
    def parameterCount(self) -> int: ...
    def parameterList(self) -> java.util.List[typing.Type[java.lang.Object]]: ...
    def parameterType(self, num: int | java.jint | java.lang.Integer, /) -> typing.Type[java.lang.Object]: ...
    def returnType(self) -> typing.Type[java.lang.Object]: ...
    def toMethodDescriptorString(self) -> str: ...
    def toString(self) -> str: ...
    def unwrap(self) -> MethodType: ...
    def wrap(self) -> MethodType: ...

class MutableCallSite(CallSite):
    @typing.overload
    def __init__(self, target: MethodHandle, /) -> None: ...
    @typing.overload
    def __init__(self, type: MethodType, /) -> None: ...
    def dynamicInvoker(self) -> MethodHandle: ...
    def getTarget(self) -> MethodHandle: ...
    def setTarget(self, newTarget: MethodHandle, /) -> None: ...

class StringConcatException(java.lang.Exception):
    @typing.overload
    def __init__(self, msg: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, msg: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...


_TypeDescriptor__OfMethod__F = typing.TypeVar('_TypeDescriptor__OfMethod__F')  # <F>
_TypeDescriptor__OfMethod__M = typing.TypeVar('_TypeDescriptor__OfMethod__M')  # <M>

_TypeDescriptor__OfField__F = typing.TypeVar('_TypeDescriptor__OfField__F')  # <F>
class TypeDescriptor(java.lang.Object):
    def descriptorString(self) -> str: ...
    class OfMethod(TypeDescriptor, typing.Generic[_TypeDescriptor__OfMethod__F, _TypeDescriptor__OfMethod__M]):
        def changeParameterType(self, arg1: int | java.jint | java.lang.Integer, arg2: _TypeDescriptor__OfMethod__F, /) -> _TypeDescriptor__OfMethod__M: ...
        def changeReturnType(self, arg1: _TypeDescriptor__OfMethod__F, /) -> _TypeDescriptor__OfMethod__M: ...
        def dropParameterTypes(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> _TypeDescriptor__OfMethod__M: ...
        def insertParameterTypes(self, arg1: int | java.jint | java.lang.Integer, /, *arg2: _TypeDescriptor__OfMethod__F) -> _TypeDescriptor__OfMethod__M: ...
        def parameterArray(self) -> java.chaquopy.JavaArray[_TypeDescriptor__OfMethod__F]: ...
        def parameterCount(self) -> int: ...
        def parameterList(self) -> java.util.List[_TypeDescriptor__OfMethod__F]: ...
        def parameterType(self, arg1: int | java.jint | java.lang.Integer, /) -> _TypeDescriptor__OfMethod__F: ...
        def returnType(self) -> _TypeDescriptor__OfMethod__F: ...
    class OfField(TypeDescriptor, typing.Generic[_TypeDescriptor__OfField__F]):
        def arrayType(self) -> _TypeDescriptor__OfField__F: ...
        def componentType(self) -> _TypeDescriptor__OfField__F: ...
        def isArray(self) -> bool: ...
        def isPrimitive(self) -> bool: ...

class VarHandle(java.lang.Object):
    def accessModeType(self, accessMode: VarHandle.AccessMode, /) -> MethodType: ...
    @staticmethod
    def acquireFence() -> None: ...
    def compareAndExchange(self, *arg1: java.lang.Object) -> java.lang.Object: ...
    def compareAndExchangeAcquire(self, *arg1: java.lang.Object) -> java.lang.Object: ...
    def compareAndExchangeRelease(self, *arg1: java.lang.Object) -> java.lang.Object: ...
    def compareAndSet(self, *arg1: java.lang.Object) -> bool: ...
    def coordinateTypes(self) -> java.util.List[typing.Type[java.lang.Object]]: ...
    @staticmethod
    def fullFence() -> None: ...
    def get(self, *arg1: java.lang.Object) -> java.lang.Object: ...
    def getAcquire(self, *arg1: java.lang.Object) -> java.lang.Object: ...
    def getAndAdd(self, *arg1: java.lang.Object) -> java.lang.Object: ...
    def getAndAddAcquire(self, *arg1: java.lang.Object) -> java.lang.Object: ...
    def getAndAddRelease(self, *arg1: java.lang.Object) -> java.lang.Object: ...
    def getAndBitwiseAnd(self, *arg1: java.lang.Object) -> java.lang.Object: ...
    def getAndBitwiseAndAcquire(self, *arg1: java.lang.Object) -> java.lang.Object: ...
    def getAndBitwiseAndRelease(self, *arg1: java.lang.Object) -> java.lang.Object: ...
    def getAndBitwiseOr(self, *arg1: java.lang.Object) -> java.lang.Object: ...
    def getAndBitwiseOrAcquire(self, *arg1: java.lang.Object) -> java.lang.Object: ...
    def getAndBitwiseOrRelease(self, *arg1: java.lang.Object) -> java.lang.Object: ...
    def getAndBitwiseXor(self, *arg1: java.lang.Object) -> java.lang.Object: ...
    def getAndBitwiseXorAcquire(self, *arg1: java.lang.Object) -> java.lang.Object: ...
    def getAndBitwiseXorRelease(self, *arg1: java.lang.Object) -> java.lang.Object: ...
    def getAndSet(self, *arg1: java.lang.Object) -> java.lang.Object: ...
    def getAndSetAcquire(self, *arg1: java.lang.Object) -> java.lang.Object: ...
    def getAndSetRelease(self, *arg1: java.lang.Object) -> java.lang.Object: ...
    def getOpaque(self, *arg1: java.lang.Object) -> java.lang.Object: ...
    def getVolatile(self, *arg1: java.lang.Object) -> java.lang.Object: ...
    def isAccessModeSupported(self, accessMode: VarHandle.AccessMode, /) -> bool: ...
    @staticmethod
    def loadLoadFence() -> None: ...
    @staticmethod
    def releaseFence() -> None: ...
    def set(self, *arg1: java.lang.Object) -> None: ...
    def setOpaque(self, *arg1: java.lang.Object) -> None: ...
    def setRelease(self, *arg1: java.lang.Object) -> None: ...
    def setVolatile(self, *arg1: java.lang.Object) -> None: ...
    @staticmethod
    def storeStoreFence() -> None: ...
    def toMethodHandle(self, accessMode: VarHandle.AccessMode, /) -> MethodHandle: ...
    def toString(self) -> str: ...
    def varType(self) -> typing.Type[java.lang.Object]: ...
    def weakCompareAndSet(self, *arg1: java.lang.Object) -> bool: ...
    def weakCompareAndSetAcquire(self, *arg1: java.lang.Object) -> bool: ...
    def weakCompareAndSetPlain(self, *arg1: java.lang.Object) -> bool: ...
    def weakCompareAndSetRelease(self, *arg1: java.lang.Object) -> bool: ...

    class AccessMode(java.lang.Enum[VarHandle.AccessMode]):
        COMPARE_AND_EXCHANGE: typing.ClassVar[VarHandle.AccessMode] = ...
        COMPARE_AND_EXCHANGE_ACQUIRE: typing.ClassVar[VarHandle.AccessMode] = ...
        COMPARE_AND_EXCHANGE_RELEASE: typing.ClassVar[VarHandle.AccessMode] = ...
        COMPARE_AND_SET: typing.ClassVar[VarHandle.AccessMode] = ...
        GET: typing.ClassVar[VarHandle.AccessMode] = ...
        GET_ACQUIRE: typing.ClassVar[VarHandle.AccessMode] = ...
        GET_AND_ADD: typing.ClassVar[VarHandle.AccessMode] = ...
        GET_AND_ADD_ACQUIRE: typing.ClassVar[VarHandle.AccessMode] = ...
        GET_AND_ADD_RELEASE: typing.ClassVar[VarHandle.AccessMode] = ...
        GET_AND_BITWISE_AND: typing.ClassVar[VarHandle.AccessMode] = ...
        GET_AND_BITWISE_AND_ACQUIRE: typing.ClassVar[VarHandle.AccessMode] = ...
        GET_AND_BITWISE_AND_RELEASE: typing.ClassVar[VarHandle.AccessMode] = ...
        GET_AND_BITWISE_OR: typing.ClassVar[VarHandle.AccessMode] = ...
        GET_AND_BITWISE_OR_ACQUIRE: typing.ClassVar[VarHandle.AccessMode] = ...
        GET_AND_BITWISE_OR_RELEASE: typing.ClassVar[VarHandle.AccessMode] = ...
        GET_AND_BITWISE_XOR: typing.ClassVar[VarHandle.AccessMode] = ...
        GET_AND_BITWISE_XOR_ACQUIRE: typing.ClassVar[VarHandle.AccessMode] = ...
        GET_AND_BITWISE_XOR_RELEASE: typing.ClassVar[VarHandle.AccessMode] = ...
        GET_AND_SET: typing.ClassVar[VarHandle.AccessMode] = ...
        GET_AND_SET_ACQUIRE: typing.ClassVar[VarHandle.AccessMode] = ...
        GET_AND_SET_RELEASE: typing.ClassVar[VarHandle.AccessMode] = ...
        GET_OPAQUE: typing.ClassVar[VarHandle.AccessMode] = ...
        GET_VOLATILE: typing.ClassVar[VarHandle.AccessMode] = ...
        SET: typing.ClassVar[VarHandle.AccessMode] = ...
        SET_OPAQUE: typing.ClassVar[VarHandle.AccessMode] = ...
        SET_RELEASE: typing.ClassVar[VarHandle.AccessMode] = ...
        SET_VOLATILE: typing.ClassVar[VarHandle.AccessMode] = ...
        WEAK_COMPARE_AND_SET: typing.ClassVar[VarHandle.AccessMode] = ...
        WEAK_COMPARE_AND_SET_ACQUIRE: typing.ClassVar[VarHandle.AccessMode] = ...
        WEAK_COMPARE_AND_SET_PLAIN: typing.ClassVar[VarHandle.AccessMode] = ...
        WEAK_COMPARE_AND_SET_RELEASE: typing.ClassVar[VarHandle.AccessMode] = ...
        def methodName(self) -> str: ...
        @staticmethod
        def valueFromMethodName(methodName: str | java.lang.String, /) -> VarHandle.AccessMode: ...
        @staticmethod
        def valueOf(name: str | java.lang.String, /) -> VarHandle.AccessMode: ...
        @staticmethod
        def values() -> java.chaquopy.JavaArray[VarHandle.AccessMode]: ...

class VolatileCallSite(CallSite):
    @typing.overload
    def __init__(self, target: MethodHandle, /) -> None: ...
    @typing.overload
    def __init__(self, type: MethodType, /) -> None: ...
    def dynamicInvoker(self) -> MethodHandle: ...
    def getTarget(self) -> MethodHandle: ...
    def setTarget(self, newTarget: MethodHandle, /) -> None: ...

class WrongMethodTypeException(java.lang.RuntimeException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, s: str | java.lang.String, /) -> None: ...



import typing

import android.app
import android.content
import android.net
import android.os
import java
import java.lang
import java.util

class WallpaperDescription(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[WallpaperDescription]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getComponent(self) -> android.content.ComponentName: ...
    def getContent(self) -> android.os.PersistableBundle: ...
    def getContextDescription(self) -> java.lang.CharSequence: ...
    def getContextUri(self) -> android.net.Uri: ...
    def getDescription(self) -> java.util.List[java.lang.CharSequence]: ...
    def getId(self) -> str: ...
    def getThumbnail(self) -> android.net.Uri: ...
    def getTitle(self) -> java.lang.CharSequence: ...
    def hashCode(self) -> int: ...
    def toBuilder(self) -> WallpaperDescription.Builder: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> WallpaperDescription: ...
        def setContent(self, content: android.os.PersistableBundle, /) -> WallpaperDescription.Builder: ...
        def setContextDescription(self, contextDescription: java.lang.CharSequence, /) -> WallpaperDescription.Builder: ...
        def setContextUri(self, contextUri: android.net.Uri, /) -> WallpaperDescription.Builder: ...
        def setDescription(self, description: java.util.List[java.lang.CharSequence], /) -> WallpaperDescription.Builder: ...
        def setId(self, id: str | java.lang.String, /) -> WallpaperDescription.Builder: ...
        def setThumbnail(self, thumbnail: android.net.Uri, /) -> WallpaperDescription.Builder: ...
        def setTitle(self, title: java.lang.CharSequence, /) -> WallpaperDescription.Builder: ...

class WallpaperInstance(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[WallpaperInstance]] = ...
    def __init__(self, info: android.app.WallpaperInfo, description: WallpaperDescription, /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getDescription(self) -> WallpaperDescription: ...
    def getId(self) -> str: ...
    def getInfo(self) -> android.app.WallpaperInfo: ...
    def hashCode(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...



import typing

import android.app.appsearch
import java
import java.lang

class AppSearchException(java.lang.Exception):
    @typing.overload
    def __init__(self, resultCode: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, resultCode: int | java.jint | java.lang.Integer, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, resultCode: int | java.jint | java.lang.Integer, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...
    def getResultCode(self) -> int: ...
    def toAppSearchResult(self) -> android.app.appsearch.AppSearchResult[java.lang.Object]: ...



import typing

import android.os
import android.view
import java
import java.chaquopy
import java.lang

class HostUsiVersion(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[HostUsiVersion]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getMajorVersion(self) -> int: ...
    def getMinorVersion(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class InputManager(java.lang.Object):
    ACTION_QUERY_KEYBOARD_LAYOUTS: typing.ClassVar[str] = ...
    META_DATA_KEYBOARD_LAYOUTS: typing.ClassVar[str] = ...
    def getHostUsiVersion(self, display: android.view.Display, /) -> HostUsiVersion | None: ...
    def getInputDevice(self, id: int | java.jint | java.lang.Integer, /) -> android.view.InputDevice | None: ...
    def getInputDeviceIds(self) -> java.chaquopy.JavaArrayJInt: ...
    def getInputDeviceViewBehavior(self, deviceId: int | java.jint | java.lang.Integer, /) -> android.view.InputDevice.ViewBehavior | None: ...
    def getMaximumObscuringOpacityForTouch(self) -> float: ...
    def isStylusPointerIconEnabled(self) -> bool: ...
    def registerInputDeviceListener(self, listener: InputManager.InputDeviceListener, handler: android.os.Handler, /) -> None: ...
    def unregisterInputDeviceListener(self, listener: InputManager.InputDeviceListener, /) -> None: ...
    def verifyInputEvent(self, event: android.view.InputEvent, /) -> android.view.VerifiedInputEvent | None: ...

    class InputDeviceListener(java.lang.Object):
        def onInputDeviceAdded(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
        def onInputDeviceChanged(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
        def onInputDeviceRemoved(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...



import typing

import android.os
import java
import java.lang

class ProviderProperties(android.os.Parcelable):
    ACCURACY_COARSE: typing.ClassVar[int] = ...
    ACCURACY_FINE: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ProviderProperties]] = ...
    POWER_USAGE_HIGH: typing.ClassVar[int] = ...
    POWER_USAGE_LOW: typing.ClassVar[int] = ...
    POWER_USAGE_MEDIUM: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAccuracy(self) -> int: ...
    def getPowerUsage(self) -> int: ...
    def hasAltitudeSupport(self) -> bool: ...
    def hasBearingSupport(self) -> bool: ...
    def hasCellRequirement(self) -> bool: ...
    def hasMonetaryCost(self) -> bool: ...
    def hasNetworkRequirement(self) -> bool: ...
    def hasSatelliteRequirement(self) -> bool: ...
    def hasSpeedSupport(self) -> bool: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, providerProperties: ProviderProperties, /) -> None: ...
        def build(self) -> ProviderProperties: ...
        def setAccuracy(self, accuracy: int | java.jint | java.lang.Integer, /) -> ProviderProperties.Builder: ...
        def setHasAltitudeSupport(self, supportsAltitude: bool | java.jboolean | java.lang.Boolean, /) -> ProviderProperties.Builder: ...
        def setHasBearingSupport(self, supportsBearing: bool | java.jboolean | java.lang.Boolean, /) -> ProviderProperties.Builder: ...
        def setHasCellRequirement(self, requiresCell: bool | java.jboolean | java.lang.Boolean, /) -> ProviderProperties.Builder: ...
        def setHasMonetaryCost(self, monetaryCost: bool | java.jboolean | java.lang.Boolean, /) -> ProviderProperties.Builder: ...
        def setHasNetworkRequirement(self, requiresNetwork: bool | java.jboolean | java.lang.Boolean, /) -> ProviderProperties.Builder: ...
        def setHasSatelliteRequirement(self, requiresSatellite: bool | java.jboolean | java.lang.Boolean, /) -> ProviderProperties.Builder: ...
        def setHasSpeedSupport(self, supportsSpeed: bool | java.jboolean | java.lang.Boolean, /) -> ProviderProperties.Builder: ...
        def setPowerUsage(self, powerUsage: int | java.jint | java.lang.Integer, /) -> ProviderProperties.Builder: ...



import typing

import android.app
import android.os
import android.view
import android.widget
import java
import java.lang
import java.time

class BackEvent(java.lang.Object):
    EDGE_LEFT: typing.ClassVar[int] = ...
    EDGE_NONE: typing.ClassVar[int] = ...
    EDGE_RIGHT: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, touchX: float | java.jfloat | java.lang.Float, touchY: float | java.jfloat | java.lang.Float, progress: float | java.jfloat | java.lang.Float, swipeEdge: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, touchX: float | java.jfloat | java.lang.Float, touchY: float | java.jfloat | java.lang.Float, progress: float | java.jfloat | java.lang.Float, swipeEdge: int | java.jint | java.lang.Integer, frameTimeMillis: int | java.jlong | java.lang.Long, /) -> None: ...
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getFrameTimeMillis(self) -> int: ...
    def getProgress(self) -> float: ...
    def getSwipeEdge(self) -> int: ...
    def getTouchX(self) -> float: ...
    def getTouchY(self) -> float: ...
    def toString(self) -> str: ...

class InputTransferToken(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[InputTransferToken]] = ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def hashCode(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class OnBackAnimationCallback(OnBackInvokedCallback):
    def onBackCancelled(self) -> None: ...
    def onBackProgressed(self, backEvent: BackEvent, /) -> None: ...
    def onBackStarted(self, backEvent: BackEvent, /) -> None: ...

class OnBackInvokedCallback(java.lang.Object):
    def onBackInvoked(self) -> None: ...

class OnBackInvokedDispatcher(java.lang.Object):
    PRIORITY_DEFAULT: typing.ClassVar[int] = ...
    PRIORITY_OVERLAY: typing.ClassVar[int] = ...
    PRIORITY_SYSTEM_NAVIGATION_OBSERVER: typing.ClassVar[int] = ...
    def registerOnBackInvokedCallback(self, arg1: int | java.jint | java.lang.Integer, arg2: OnBackInvokedCallback, /) -> None: ...
    def unregisterOnBackInvokedCallback(self, arg1: OnBackInvokedCallback, /) -> None: ...

class SplashScreen(java.lang.Object):
    SPLASH_SCREEN_STYLE_ICON: typing.ClassVar[int] = ...
    SPLASH_SCREEN_STYLE_SOLID_COLOR: typing.ClassVar[int] = ...
    def clearOnExitAnimationListener(self) -> None: ...
    def setOnExitAnimationListener(self, arg1: SplashScreen.OnExitAnimationListener, /) -> None: ...
    def setSplashScreenTheme(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...

    class OnExitAnimationListener(java.lang.Object):
        def onSplashScreenExit(self, arg1: SplashScreenView, /) -> None: ...

class SplashScreenView(android.widget.FrameLayout):
    def getIconAnimationDuration(self) -> java.time.Duration | None: ...
    def getIconAnimationStart(self) -> java.time.Instant | None: ...
    def getIconView(self) -> android.view.View | None: ...
    def onDetachedFromWindow(self) -> None: ...
    def onLayout(self, changed: bool | java.jboolean | java.lang.Boolean, l: int | java.jint | java.lang.Integer, t: int | java.jint | java.lang.Integer, r: int | java.jint | java.lang.Integer, b: int | java.jint | java.lang.Integer, /) -> None: ...
    def remove(self) -> None: ...
    def setAlpha(self, alpha: float | java.jfloat | java.lang.Float, /) -> None: ...

class SurfaceSyncGroup(java.lang.Object):
    def __init__(self, name: str | java.lang.String, /) -> None: ...
    @typing.overload
    def add(self, attachedSurfaceControl: android.view.AttachedSurfaceControl, runnable: java.lang.Runnable, /) -> bool: ...
    @typing.overload
    def add(self, surfacePackage: android.view.SurfaceControlViewHost.SurfacePackage, runnable: java.lang.Runnable, /) -> bool: ...
    def addTransaction(self, transaction: android.view.SurfaceControl.Transaction, /) -> None: ...
    def markSyncReady(self) -> None: ...

class SystemOnBackInvokedCallbacks(java.lang.Object):
    @staticmethod
    def finishAndRemoveTaskCallback(activity: android.app.Activity, /) -> OnBackInvokedCallback: ...
    @staticmethod
    def moveTaskToBackCallback(activity: android.app.Activity, /) -> OnBackInvokedCallback: ...

class TrustedPresentationThresholds(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[TrustedPresentationThresholds]] = ...
    def __init__(self, minAlpha: float | java.jfloat | java.lang.Float, minFractionRendered: float | java.jfloat | java.lang.Float, stabilityRequirementMs: int | java.jint | java.lang.Integer, /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getMinAlpha(self) -> float: ...
    def getMinFractionRendered(self) -> float: ...
    def getStabilityRequirementMillis(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...



import typing

import android.app
import android.icu.util
import android.os
import android.util
import android.view
import android.view.autofill
import java
import java.lang
import java.util
import java.util.concurrent
import java.util.function

class TranslationCapability(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[TranslationCapability]] = ...
    STATE_AVAILABLE_TO_DOWNLOAD: typing.ClassVar[int] = ...
    STATE_DOWNLOADING: typing.ClassVar[int] = ...
    STATE_NOT_AVAILABLE: typing.ClassVar[int] = ...
    STATE_ON_DEVICE: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def getSourceSpec(self) -> TranslationSpec: ...
    def getState(self) -> int: ...
    def getSupportedTranslationFlags(self) -> int: ...
    def getTargetSpec(self) -> TranslationSpec: ...
    def isUiTranslationEnabled(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class TranslationContext(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[TranslationContext]] = ...
    FLAG_DEFINITIONS: typing.ClassVar[int] = ...
    FLAG_LOW_LATENCY: typing.ClassVar[int] = ...
    FLAG_TRANSLITERATION: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def getSourceSpec(self) -> TranslationSpec: ...
    def getTargetSpec(self) -> TranslationSpec: ...
    def getTranslationFlags(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, sourceSpec: TranslationSpec, targetSpec: TranslationSpec, /) -> None: ...
        def build(self) -> TranslationContext: ...
        def setTranslationFlags(self, value: int | java.jint | java.lang.Integer, /) -> TranslationContext.Builder: ...

class TranslationManager(java.lang.Object):
    def addOnDeviceTranslationCapabilityUpdateListener(self, executor: java.util.concurrent.Executor, capabilityListener: java.util.function.Consumer[TranslationCapability], /) -> None: ...
    def createOnDeviceTranslator(self, translationContext: TranslationContext, executor: java.util.concurrent.Executor, callback: java.util.function.Consumer[Translator], /) -> None: ...
    def getOnDeviceTranslationCapabilities(self, sourceFormat: int | java.jint | java.lang.Integer, targetFormat: int | java.jint | java.lang.Integer, /) -> java.util.Set[TranslationCapability]: ...
    def getOnDeviceTranslationSettingsActivityIntent(self) -> android.app.PendingIntent | None: ...
    def removeOnDeviceTranslationCapabilityUpdateListener(self, capabilityListener: java.util.function.Consumer[TranslationCapability], /) -> None: ...

class TranslationRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[TranslationRequest]] = ...
    FLAG_DICTIONARY_RESULT: typing.ClassVar[int] = ...
    FLAG_PARTIAL_RESPONSES: typing.ClassVar[int] = ...
    FLAG_TRANSLATION_RESULT: typing.ClassVar[int] = ...
    FLAG_TRANSLITERATION_RESULT: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def getFlags(self) -> int: ...
    def getTranslationRequestValues(self) -> java.util.List[TranslationRequestValue]: ...
    def getViewTranslationRequests(self) -> java.util.List[ViewTranslationRequest]: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> TranslationRequest: ...
        def setFlags(self, value: int | java.jint | java.lang.Integer, /) -> TranslationRequest.Builder: ...
        def setTranslationRequestValues(self, value: java.util.List[TranslationRequestValue], /) -> TranslationRequest.Builder: ...
        def setViewTranslationRequests(self, value: java.util.List[ViewTranslationRequest], /) -> TranslationRequest.Builder: ...

class TranslationRequestValue(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[TranslationRequestValue]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def forText(text: java.lang.CharSequence, /) -> TranslationRequestValue: ...
    def getText(self) -> java.lang.CharSequence | None: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class TranslationResponse(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[TranslationResponse]] = ...
    TRANSLATION_STATUS_CONTEXT_UNSUPPORTED: typing.ClassVar[int] = ...
    TRANSLATION_STATUS_SUCCESS: typing.ClassVar[int] = ...
    TRANSLATION_STATUS_UNKNOWN_ERROR: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def getTranslationResponseValues(self) -> android.util.SparseArray[TranslationResponseValue]: ...
    def getTranslationStatus(self) -> int: ...
    def getViewTranslationResponses(self) -> android.util.SparseArray[ViewTranslationResponse]: ...
    def isFinalResponse(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, translationStatus: int | java.jint | java.lang.Integer, /) -> None: ...
        def build(self) -> TranslationResponse: ...
        def setFinalResponse(self, value: bool | java.jboolean | java.lang.Boolean, /) -> TranslationResponse.Builder: ...
        def setTranslationResponseValue(self, index: int | java.jint | java.lang.Integer, value: TranslationResponseValue, /) -> TranslationResponse.Builder: ...
        def setTranslationResponseValues(self, value: android.util.SparseArray[TranslationResponseValue], /) -> TranslationResponse.Builder: ...
        def setViewTranslationResponse(self, index: int | java.jint | java.lang.Integer, response: ViewTranslationResponse, /) -> TranslationResponse.Builder: ...
        def setViewTranslationResponses(self, value: android.util.SparseArray[ViewTranslationResponse], /) -> TranslationResponse.Builder: ...

class TranslationResponseValue(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[TranslationResponseValue]] = ...
    EXTRA_DEFINITIONS: typing.ClassVar[str] = ...
    STATUS_ERROR: typing.ClassVar[int] = ...
    STATUS_SUCCESS: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def forError() -> TranslationResponseValue: ...
    def getExtras(self) -> android.os.Bundle: ...
    def getStatusCode(self) -> int: ...
    def getText(self) -> java.lang.CharSequence | None: ...
    def getTransliteration(self) -> java.lang.CharSequence | None: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, statusCode: int | java.jint | java.lang.Integer, /) -> None: ...
        def build(self) -> TranslationResponseValue: ...
        def setExtras(self, value: android.os.Bundle, /) -> TranslationResponseValue.Builder: ...
        def setText(self, value: java.lang.CharSequence, /) -> TranslationResponseValue.Builder: ...
        def setTransliteration(self, value: java.lang.CharSequence, /) -> TranslationResponseValue.Builder: ...

class TranslationSpec(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[TranslationSpec]] = ...
    DATA_FORMAT_TEXT: typing.ClassVar[int] = ...
    def __init__(self, locale: android.icu.util.ULocale, dataFormat: int | java.jint | java.lang.Integer, /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getDataFormat(self) -> int: ...
    def getLocale(self) -> android.icu.util.ULocale: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class Translator(java.lang.Object):
    def destroy(self) -> None: ...
    def isDestroyed(self) -> bool: ...
    def translate(self, request: TranslationRequest, cancellationSignal: android.os.CancellationSignal, executor: java.util.concurrent.Executor, callback: java.util.function.Consumer[TranslationResponse], /) -> None: ...

class UiTranslationManager(java.lang.Object):
    def registerUiTranslationStateCallback(self, executor: java.util.concurrent.Executor, callback: UiTranslationStateCallback, /) -> None: ...
    def unregisterUiTranslationStateCallback(self, callback: UiTranslationStateCallback, /) -> None: ...

class UiTranslationStateCallback(java.lang.Object):
    @typing.overload
    def onFinished(self) -> None: ...
    @typing.overload
    def onFinished(self, packageName: str | java.lang.String, /) -> None: ...
    @typing.overload
    def onPaused(self) -> None: ...
    @typing.overload
    def onPaused(self, packageName: str | java.lang.String, /) -> None: ...
    @typing.overload
    def onResumed(self, sourceLocale: android.icu.util.ULocale, targetLocale: android.icu.util.ULocale, /) -> None: ...
    @typing.overload
    def onResumed(self, sourceLocale: android.icu.util.ULocale, targetLocale: android.icu.util.ULocale, packageName: str | java.lang.String, /) -> None: ...
    @typing.overload
    def onStarted(self, sourceLocale: android.icu.util.ULocale, targetLocale: android.icu.util.ULocale, /) -> None: ...
    @typing.overload
    def onStarted(self, sourceLocale: android.icu.util.ULocale, targetLocale: android.icu.util.ULocale, packageName: str | java.lang.String, /) -> None: ...

class ViewTranslationCallback(java.lang.Object):
    def onClearTranslation(self, arg1: android.view.View, /) -> bool: ...
    def onHideTranslation(self, arg1: android.view.View, /) -> bool: ...
    def onShowTranslation(self, arg1: android.view.View, /) -> bool: ...

class ViewTranslationRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ViewTranslationRequest]] = ...
    ID_TEXT: typing.ClassVar[str] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAutofillId(self) -> android.view.autofill.AutofillId: ...
    def getKeys(self) -> java.util.Set[java.lang.String]: ...
    def getValue(self, key: str | java.lang.String, /) -> TranslationRequestValue: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self, autofillId: android.view.autofill.AutofillId, /) -> None: ...
        @typing.overload
        def __init__(self, autofillId: android.view.autofill.AutofillId, virtualChildId: int | java.jlong | java.lang.Long, /) -> None: ...
        def build(self) -> ViewTranslationRequest: ...
        def setValue(self, key: str | java.lang.String, value: TranslationRequestValue, /) -> ViewTranslationRequest.Builder: ...

class ViewTranslationResponse(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ViewTranslationResponse]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAutofillId(self) -> android.view.autofill.AutofillId: ...
    def getKeys(self) -> java.util.Set[java.lang.String]: ...
    def getValue(self, key: str | java.lang.String, /) -> TranslationResponseValue: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, autofillId: android.view.autofill.AutofillId, /) -> None: ...
        def build(self) -> ViewTranslationResponse: ...
        def setValue(self, key: str | java.lang.String, value: TranslationResponseValue, /) -> ViewTranslationResponse.Builder: ...



import typing

import java
import java.chaquopy
import java.io
import java.lang

class Callback(java.lang.Object): ...

class CallbackHandler(java.lang.Object):
    def handle(self, arg1: java.chaquopy.JavaArray[Callback], /) -> None: ...

class PasswordCallback(Callback, java.io.Serializable):
    def __init__(self, prompt: str | java.lang.String, echoOn: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def clearPassword(self) -> None: ...
    def getPassword(self) -> java.chaquopy.JavaArrayJChar: ...
    def getPrompt(self) -> str: ...
    def isEchoOn(self) -> bool: ...
    def setPassword(self, password: java.chaquopy.JavaArrayJChar, /) -> None: ...

class UnsupportedCallbackException(java.lang.Exception):
    @typing.overload
    def __init__(self, callback: Callback, /) -> None: ...
    @typing.overload
    def __init__(self, callback: Callback, msg: str | java.lang.String, /) -> None: ...
    def getCallback(self) -> Callback: ...
